# coding: utf-8

"""
    Selling Partner API for Orders

    The Selling Partner API for Orders helps you programmatically retrieve order information. These APIs let you develop fast, flexible, custom applications in areas like order synchronization, order research, and demand-based decision support tools.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Order(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amazon_order_id': 'str',
        'seller_order_id': 'str',
        'purchase_date': 'str',
        'last_update_date': 'str',
        'order_status': 'str',
        'fulfillment_channel': 'str',
        'sales_channel': 'str',
        'order_channel': 'str',
        'ship_service_level': 'str',
        'order_total': 'Money',
        'number_of_items_shipped': 'int',
        'number_of_items_unshipped': 'int',
        'payment_execution_detail': 'PaymentExecutionDetailItemList',
        'payment_method': 'str',
        'payment_method_details': 'PaymentMethodDetailItemList',
        'marketplace_id': 'str',
        'shipment_service_level_category': 'str',
        'easy_ship_shipment_status': 'str',
        'cba_displayable_shipping_label': 'str',
        'order_type': 'str',
        'earliest_ship_date': 'str',
        'latest_ship_date': 'str',
        'earliest_delivery_date': 'str',
        'latest_delivery_date': 'str',
        'is_business_order': 'bool',
        'is_prime': 'bool',
        'is_premium_order': 'bool',
        'is_global_express_enabled': 'bool',
        'replaced_order_id': 'str',
        'is_replacement_order': 'bool',
        'promise_response_due_date': 'str',
        'is_estimated_ship_date_set': 'bool',
        'is_sold_by_ab': 'bool',
        'assigned_ship_from_location_address': 'Address',
        'fulfillment_instruction': 'FulfillmentInstruction'
    }

    attribute_map = {
        'amazon_order_id': 'AmazonOrderId',
        'seller_order_id': 'SellerOrderId',
        'purchase_date': 'PurchaseDate',
        'last_update_date': 'LastUpdateDate',
        'order_status': 'OrderStatus',
        'fulfillment_channel': 'FulfillmentChannel',
        'sales_channel': 'SalesChannel',
        'order_channel': 'OrderChannel',
        'ship_service_level': 'ShipServiceLevel',
        'order_total': 'OrderTotal',
        'number_of_items_shipped': 'NumberOfItemsShipped',
        'number_of_items_unshipped': 'NumberOfItemsUnshipped',
        'payment_execution_detail': 'PaymentExecutionDetail',
        'payment_method': 'PaymentMethod',
        'payment_method_details': 'PaymentMethodDetails',
        'marketplace_id': 'MarketplaceId',
        'shipment_service_level_category': 'ShipmentServiceLevelCategory',
        'easy_ship_shipment_status': 'EasyShipShipmentStatus',
        'cba_displayable_shipping_label': 'CbaDisplayableShippingLabel',
        'order_type': 'OrderType',
        'earliest_ship_date': 'EarliestShipDate',
        'latest_ship_date': 'LatestShipDate',
        'earliest_delivery_date': 'EarliestDeliveryDate',
        'latest_delivery_date': 'LatestDeliveryDate',
        'is_business_order': 'IsBusinessOrder',
        'is_prime': 'IsPrime',
        'is_premium_order': 'IsPremiumOrder',
        'is_global_express_enabled': 'IsGlobalExpressEnabled',
        'replaced_order_id': 'ReplacedOrderId',
        'is_replacement_order': 'IsReplacementOrder',
        'promise_response_due_date': 'PromiseResponseDueDate',
        'is_estimated_ship_date_set': 'IsEstimatedShipDateSet',
        'is_sold_by_ab': 'IsSoldByAB',
        'assigned_ship_from_location_address': 'AssignedShipFromLocationAddress',
        'fulfillment_instruction': 'FulfillmentInstruction'
    }

    def __init__(self, amazon_order_id=None, seller_order_id=None, purchase_date=None, last_update_date=None, order_status=None, fulfillment_channel=None, sales_channel=None, order_channel=None, ship_service_level=None, order_total=None, number_of_items_shipped=None, number_of_items_unshipped=None, payment_execution_detail=None, payment_method=None, payment_method_details=None, marketplace_id=None, shipment_service_level_category=None, easy_ship_shipment_status=None, cba_displayable_shipping_label=None, order_type=None, earliest_ship_date=None, latest_ship_date=None, earliest_delivery_date=None, latest_delivery_date=None, is_business_order=None, is_prime=None, is_premium_order=None, is_global_express_enabled=None, replaced_order_id=None, is_replacement_order=None, promise_response_due_date=None, is_estimated_ship_date_set=None, is_sold_by_ab=None, assigned_ship_from_location_address=None, fulfillment_instruction=None):  # noqa: E501
        """Order - a model defined in Swagger"""  # noqa: E501
        self._amazon_order_id = None
        self._seller_order_id = None
        self._purchase_date = None
        self._last_update_date = None
        self._order_status = None
        self._fulfillment_channel = None
        self._sales_channel = None
        self._order_channel = None
        self._ship_service_level = None
        self._order_total = None
        self._number_of_items_shipped = None
        self._number_of_items_unshipped = None
        self._payment_execution_detail = None
        self._payment_method = None
        self._payment_method_details = None
        self._marketplace_id = None
        self._shipment_service_level_category = None
        self._easy_ship_shipment_status = None
        self._cba_displayable_shipping_label = None
        self._order_type = None
        self._earliest_ship_date = None
        self._latest_ship_date = None
        self._earliest_delivery_date = None
        self._latest_delivery_date = None
        self._is_business_order = None
        self._is_prime = None
        self._is_premium_order = None
        self._is_global_express_enabled = None
        self._replaced_order_id = None
        self._is_replacement_order = None
        self._promise_response_due_date = None
        self._is_estimated_ship_date_set = None
        self._is_sold_by_ab = None
        self._assigned_ship_from_location_address = None
        self._fulfillment_instruction = None
        self.discriminator = None
        self.amazon_order_id = amazon_order_id
        if seller_order_id is not None:
            self.seller_order_id = seller_order_id
        self.purchase_date = purchase_date
        self.last_update_date = last_update_date
        self.order_status = order_status
        if fulfillment_channel is not None:
            self.fulfillment_channel = fulfillment_channel
        if sales_channel is not None:
            self.sales_channel = sales_channel
        if order_channel is not None:
            self.order_channel = order_channel
        if ship_service_level is not None:
            self.ship_service_level = ship_service_level
        if order_total is not None:
            self.order_total = order_total
        if number_of_items_shipped is not None:
            self.number_of_items_shipped = number_of_items_shipped
        if number_of_items_unshipped is not None:
            self.number_of_items_unshipped = number_of_items_unshipped
        if payment_execution_detail is not None:
            self.payment_execution_detail = payment_execution_detail
        if payment_method is not None:
            self.payment_method = payment_method
        if payment_method_details is not None:
            self.payment_method_details = payment_method_details
        if marketplace_id is not None:
            self.marketplace_id = marketplace_id
        if shipment_service_level_category is not None:
            self.shipment_service_level_category = shipment_service_level_category
        if easy_ship_shipment_status is not None:
            self.easy_ship_shipment_status = easy_ship_shipment_status
        if cba_displayable_shipping_label is not None:
            self.cba_displayable_shipping_label = cba_displayable_shipping_label
        if order_type is not None:
            self.order_type = order_type
        if earliest_ship_date is not None:
            self.earliest_ship_date = earliest_ship_date
        if latest_ship_date is not None:
            self.latest_ship_date = latest_ship_date
        if earliest_delivery_date is not None:
            self.earliest_delivery_date = earliest_delivery_date
        if latest_delivery_date is not None:
            self.latest_delivery_date = latest_delivery_date
        if is_business_order is not None:
            self.is_business_order = is_business_order
        if is_prime is not None:
            self.is_prime = is_prime
        if is_premium_order is not None:
            self.is_premium_order = is_premium_order
        if is_global_express_enabled is not None:
            self.is_global_express_enabled = is_global_express_enabled
        if replaced_order_id is not None:
            self.replaced_order_id = replaced_order_id
        if is_replacement_order is not None:
            self.is_replacement_order = is_replacement_order
        if promise_response_due_date is not None:
            self.promise_response_due_date = promise_response_due_date
        if is_estimated_ship_date_set is not None:
            self.is_estimated_ship_date_set = is_estimated_ship_date_set
        if is_sold_by_ab is not None:
            self.is_sold_by_ab = is_sold_by_ab
        if assigned_ship_from_location_address is not None:
            self.assigned_ship_from_location_address = assigned_ship_from_location_address
        if fulfillment_instruction is not None:
            self.fulfillment_instruction = fulfillment_instruction

    @property
    def amazon_order_id(self):
        """Gets the amazon_order_id of this Order.  # noqa: E501

        An Amazon-defined order identifier, in 3-7-7 format.  # noqa: E501

        :return: The amazon_order_id of this Order.  # noqa: E501
        :rtype: str
        """
        return self._amazon_order_id

    @amazon_order_id.setter
    def amazon_order_id(self, amazon_order_id):
        """Sets the amazon_order_id of this Order.

        An Amazon-defined order identifier, in 3-7-7 format.  # noqa: E501

        :param amazon_order_id: The amazon_order_id of this Order.  # noqa: E501
        :type: str
        """
        if amazon_order_id is None:
            raise ValueError("Invalid value for `amazon_order_id`, must not be `None`")  # noqa: E501

        self._amazon_order_id = amazon_order_id

    @property
    def seller_order_id(self):
        """Gets the seller_order_id of this Order.  # noqa: E501

        A seller-defined order identifier.  # noqa: E501

        :return: The seller_order_id of this Order.  # noqa: E501
        :rtype: str
        """
        return self._seller_order_id

    @seller_order_id.setter
    def seller_order_id(self, seller_order_id):
        """Sets the seller_order_id of this Order.

        A seller-defined order identifier.  # noqa: E501

        :param seller_order_id: The seller_order_id of this Order.  # noqa: E501
        :type: str
        """

        self._seller_order_id = seller_order_id

    @property
    def purchase_date(self):
        """Gets the purchase_date of this Order.  # noqa: E501

        The date when the order was created.  # noqa: E501

        :return: The purchase_date of this Order.  # noqa: E501
        :rtype: str
        """
        return self._purchase_date

    @purchase_date.setter
    def purchase_date(self, purchase_date):
        """Sets the purchase_date of this Order.

        The date when the order was created.  # noqa: E501

        :param purchase_date: The purchase_date of this Order.  # noqa: E501
        :type: str
        """
        if purchase_date is None:
            raise ValueError("Invalid value for `purchase_date`, must not be `None`")  # noqa: E501

        self._purchase_date = purchase_date

    @property
    def last_update_date(self):
        """Gets the last_update_date of this Order.  # noqa: E501

        The date when the order was last updated.  Note: LastUpdateDate is returned with an incorrect date for orders that were last updated before 2009-04-01.  # noqa: E501

        :return: The last_update_date of this Order.  # noqa: E501
        :rtype: str
        """
        return self._last_update_date

    @last_update_date.setter
    def last_update_date(self, last_update_date):
        """Sets the last_update_date of this Order.

        The date when the order was last updated.  Note: LastUpdateDate is returned with an incorrect date for orders that were last updated before 2009-04-01.  # noqa: E501

        :param last_update_date: The last_update_date of this Order.  # noqa: E501
        :type: str
        """
        if last_update_date is None:
            raise ValueError("Invalid value for `last_update_date`, must not be `None`")  # noqa: E501

        self._last_update_date = last_update_date

    @property
    def order_status(self):
        """Gets the order_status of this Order.  # noqa: E501

        The current order status.  # noqa: E501

        :return: The order_status of this Order.  # noqa: E501
        :rtype: str
        """
        return self._order_status

    @order_status.setter
    def order_status(self, order_status):
        """Sets the order_status of this Order.

        The current order status.  # noqa: E501

        :param order_status: The order_status of this Order.  # noqa: E501
        :type: str
        """
        if order_status is None:
            raise ValueError("Invalid value for `order_status`, must not be `None`")  # noqa: E501
        allowed_values = ["Pending", "Unshipped", "PartiallyShipped", "Shipped", "Canceled", "Unfulfillable", "InvoiceUnconfirmed", "PendingAvailability"]  # noqa: E501
        if order_status not in allowed_values:
            raise ValueError(
                "Invalid value for `order_status` ({0}), must be one of {1}"  # noqa: E501
                .format(order_status, allowed_values)
            )

        self._order_status = order_status

    @property
    def fulfillment_channel(self):
        """Gets the fulfillment_channel of this Order.  # noqa: E501

        Whether the order was fulfilled by Amazon (AFN) or by the seller (MFN).  # noqa: E501

        :return: The fulfillment_channel of this Order.  # noqa: E501
        :rtype: str
        """
        return self._fulfillment_channel

    @fulfillment_channel.setter
    def fulfillment_channel(self, fulfillment_channel):
        """Sets the fulfillment_channel of this Order.

        Whether the order was fulfilled by Amazon (AFN) or by the seller (MFN).  # noqa: E501

        :param fulfillment_channel: The fulfillment_channel of this Order.  # noqa: E501
        :type: str
        """
        allowed_values = ["MFN", "AFN"]  # noqa: E501
        if fulfillment_channel not in allowed_values:
            raise ValueError(
                "Invalid value for `fulfillment_channel` ({0}), must be one of {1}"  # noqa: E501
                .format(fulfillment_channel, allowed_values)
            )

        self._fulfillment_channel = fulfillment_channel

    @property
    def sales_channel(self):
        """Gets the sales_channel of this Order.  # noqa: E501

        The sales channel of the first item in the order.  # noqa: E501

        :return: The sales_channel of this Order.  # noqa: E501
        :rtype: str
        """
        return self._sales_channel

    @sales_channel.setter
    def sales_channel(self, sales_channel):
        """Sets the sales_channel of this Order.

        The sales channel of the first item in the order.  # noqa: E501

        :param sales_channel: The sales_channel of this Order.  # noqa: E501
        :type: str
        """

        self._sales_channel = sales_channel

    @property
    def order_channel(self):
        """Gets the order_channel of this Order.  # noqa: E501

        The order channel of the first item in the order.  # noqa: E501

        :return: The order_channel of this Order.  # noqa: E501
        :rtype: str
        """
        return self._order_channel

    @order_channel.setter
    def order_channel(self, order_channel):
        """Sets the order_channel of this Order.

        The order channel of the first item in the order.  # noqa: E501

        :param order_channel: The order_channel of this Order.  # noqa: E501
        :type: str
        """

        self._order_channel = order_channel

    @property
    def ship_service_level(self):
        """Gets the ship_service_level of this Order.  # noqa: E501

        The shipment service level of the order.  # noqa: E501

        :return: The ship_service_level of this Order.  # noqa: E501
        :rtype: str
        """
        return self._ship_service_level

    @ship_service_level.setter
    def ship_service_level(self, ship_service_level):
        """Sets the ship_service_level of this Order.

        The shipment service level of the order.  # noqa: E501

        :param ship_service_level: The ship_service_level of this Order.  # noqa: E501
        :type: str
        """

        self._ship_service_level = ship_service_level

    @property
    def order_total(self):
        """Gets the order_total of this Order.  # noqa: E501


        :return: The order_total of this Order.  # noqa: E501
        :rtype: Money
        """
        return self._order_total

    @order_total.setter
    def order_total(self, order_total):
        """Sets the order_total of this Order.


        :param order_total: The order_total of this Order.  # noqa: E501
        :type: Money
        """

        self._order_total = order_total

    @property
    def number_of_items_shipped(self):
        """Gets the number_of_items_shipped of this Order.  # noqa: E501

        The number of items shipped.  # noqa: E501

        :return: The number_of_items_shipped of this Order.  # noqa: E501
        :rtype: int
        """
        return self._number_of_items_shipped

    @number_of_items_shipped.setter
    def number_of_items_shipped(self, number_of_items_shipped):
        """Sets the number_of_items_shipped of this Order.

        The number of items shipped.  # noqa: E501

        :param number_of_items_shipped: The number_of_items_shipped of this Order.  # noqa: E501
        :type: int
        """

        self._number_of_items_shipped = number_of_items_shipped

    @property
    def number_of_items_unshipped(self):
        """Gets the number_of_items_unshipped of this Order.  # noqa: E501

        The number of items unshipped.  # noqa: E501

        :return: The number_of_items_unshipped of this Order.  # noqa: E501
        :rtype: int
        """
        return self._number_of_items_unshipped

    @number_of_items_unshipped.setter
    def number_of_items_unshipped(self, number_of_items_unshipped):
        """Sets the number_of_items_unshipped of this Order.

        The number of items unshipped.  # noqa: E501

        :param number_of_items_unshipped: The number_of_items_unshipped of this Order.  # noqa: E501
        :type: int
        """

        self._number_of_items_unshipped = number_of_items_unshipped

    @property
    def payment_execution_detail(self):
        """Gets the payment_execution_detail of this Order.  # noqa: E501


        :return: The payment_execution_detail of this Order.  # noqa: E501
        :rtype: PaymentExecutionDetailItemList
        """
        return self._payment_execution_detail

    @payment_execution_detail.setter
    def payment_execution_detail(self, payment_execution_detail):
        """Sets the payment_execution_detail of this Order.


        :param payment_execution_detail: The payment_execution_detail of this Order.  # noqa: E501
        :type: PaymentExecutionDetailItemList
        """

        self._payment_execution_detail = payment_execution_detail

    @property
    def payment_method(self):
        """Gets the payment_method of this Order.  # noqa: E501

        The payment method for the order. This property is limited to Cash On Delivery (COD) and Convenience Store (CVS) payment methods. Unless you need the specific COD payment information provided by the PaymentExecutionDetailItem object, we recommend using the PaymentMethodDetails property to get payment method information.  # noqa: E501

        :return: The payment_method of this Order.  # noqa: E501
        :rtype: str
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this Order.

        The payment method for the order. This property is limited to Cash On Delivery (COD) and Convenience Store (CVS) payment methods. Unless you need the specific COD payment information provided by the PaymentExecutionDetailItem object, we recommend using the PaymentMethodDetails property to get payment method information.  # noqa: E501

        :param payment_method: The payment_method of this Order.  # noqa: E501
        :type: str
        """
        allowed_values = ["COD", "CVS", "Other"]  # noqa: E501
        if payment_method not in allowed_values:
            raise ValueError(
                "Invalid value for `payment_method` ({0}), must be one of {1}"  # noqa: E501
                .format(payment_method, allowed_values)
            )

        self._payment_method = payment_method

    @property
    def payment_method_details(self):
        """Gets the payment_method_details of this Order.  # noqa: E501


        :return: The payment_method_details of this Order.  # noqa: E501
        :rtype: PaymentMethodDetailItemList
        """
        return self._payment_method_details

    @payment_method_details.setter
    def payment_method_details(self, payment_method_details):
        """Sets the payment_method_details of this Order.


        :param payment_method_details: The payment_method_details of this Order.  # noqa: E501
        :type: PaymentMethodDetailItemList
        """

        self._payment_method_details = payment_method_details

    @property
    def marketplace_id(self):
        """Gets the marketplace_id of this Order.  # noqa: E501

        The identifier for the marketplace where the order was placed.  # noqa: E501

        :return: The marketplace_id of this Order.  # noqa: E501
        :rtype: str
        """
        return self._marketplace_id

    @marketplace_id.setter
    def marketplace_id(self, marketplace_id):
        """Sets the marketplace_id of this Order.

        The identifier for the marketplace where the order was placed.  # noqa: E501

        :param marketplace_id: The marketplace_id of this Order.  # noqa: E501
        :type: str
        """

        self._marketplace_id = marketplace_id

    @property
    def shipment_service_level_category(self):
        """Gets the shipment_service_level_category of this Order.  # noqa: E501

        The shipment service level category of the order.  Possible values: Expedited, FreeEconomy, NextDay, SameDay, SecondDay, Scheduled, Standard.  # noqa: E501

        :return: The shipment_service_level_category of this Order.  # noqa: E501
        :rtype: str
        """
        return self._shipment_service_level_category

    @shipment_service_level_category.setter
    def shipment_service_level_category(self, shipment_service_level_category):
        """Sets the shipment_service_level_category of this Order.

        The shipment service level category of the order.  Possible values: Expedited, FreeEconomy, NextDay, SameDay, SecondDay, Scheduled, Standard.  # noqa: E501

        :param shipment_service_level_category: The shipment_service_level_category of this Order.  # noqa: E501
        :type: str
        """

        self._shipment_service_level_category = shipment_service_level_category

    @property
    def easy_ship_shipment_status(self):
        """Gets the easy_ship_shipment_status of this Order.  # noqa: E501

        The status of the Amazon Easy Ship order. This property is included only for Amazon Easy Ship orders.  Possible values: PendingPickUp, LabelCanceled, PickedUp, OutForDelivery, Damaged, Delivered, RejectedByBuyer, Undeliverable, ReturnedToSeller, ReturningToSeller.  # noqa: E501

        :return: The easy_ship_shipment_status of this Order.  # noqa: E501
        :rtype: str
        """
        return self._easy_ship_shipment_status

    @easy_ship_shipment_status.setter
    def easy_ship_shipment_status(self, easy_ship_shipment_status):
        """Sets the easy_ship_shipment_status of this Order.

        The status of the Amazon Easy Ship order. This property is included only for Amazon Easy Ship orders.  Possible values: PendingPickUp, LabelCanceled, PickedUp, OutForDelivery, Damaged, Delivered, RejectedByBuyer, Undeliverable, ReturnedToSeller, ReturningToSeller.  # noqa: E501

        :param easy_ship_shipment_status: The easy_ship_shipment_status of this Order.  # noqa: E501
        :type: str
        """

        self._easy_ship_shipment_status = easy_ship_shipment_status

    @property
    def cba_displayable_shipping_label(self):
        """Gets the cba_displayable_shipping_label of this Order.  # noqa: E501

        Custom ship label for Checkout by Amazon (CBA).  # noqa: E501

        :return: The cba_displayable_shipping_label of this Order.  # noqa: E501
        :rtype: str
        """
        return self._cba_displayable_shipping_label

    @cba_displayable_shipping_label.setter
    def cba_displayable_shipping_label(self, cba_displayable_shipping_label):
        """Sets the cba_displayable_shipping_label of this Order.

        Custom ship label for Checkout by Amazon (CBA).  # noqa: E501

        :param cba_displayable_shipping_label: The cba_displayable_shipping_label of this Order.  # noqa: E501
        :type: str
        """

        self._cba_displayable_shipping_label = cba_displayable_shipping_label

    @property
    def order_type(self):
        """Gets the order_type of this Order.  # noqa: E501

        The type of the order.  # noqa: E501

        :return: The order_type of this Order.  # noqa: E501
        :rtype: str
        """
        return self._order_type

    @order_type.setter
    def order_type(self, order_type):
        """Sets the order_type of this Order.

        The type of the order.  # noqa: E501

        :param order_type: The order_type of this Order.  # noqa: E501
        :type: str
        """
        allowed_values = ["StandardOrder", "LongLeadTimeOrder", "Preorder", "BackOrder", "SourcingOnDemandOrder"]  # noqa: E501
        if order_type not in allowed_values:
            raise ValueError(
                "Invalid value for `order_type` ({0}), must be one of {1}"  # noqa: E501
                .format(order_type, allowed_values)
            )

        self._order_type = order_type

    @property
    def earliest_ship_date(self):
        """Gets the earliest_ship_date of this Order.  # noqa: E501

        The start of the time period within which you have committed to ship the order. In ISO 8601 date time format. Returned only for seller-fulfilled orders.  Note: EarliestShipDate might not be returned for orders placed before February 1, 2013.  # noqa: E501

        :return: The earliest_ship_date of this Order.  # noqa: E501
        :rtype: str
        """
        return self._earliest_ship_date

    @earliest_ship_date.setter
    def earliest_ship_date(self, earliest_ship_date):
        """Sets the earliest_ship_date of this Order.

        The start of the time period within which you have committed to ship the order. In ISO 8601 date time format. Returned only for seller-fulfilled orders.  Note: EarliestShipDate might not be returned for orders placed before February 1, 2013.  # noqa: E501

        :param earliest_ship_date: The earliest_ship_date of this Order.  # noqa: E501
        :type: str
        """

        self._earliest_ship_date = earliest_ship_date

    @property
    def latest_ship_date(self):
        """Gets the latest_ship_date of this Order.  # noqa: E501

        The end of the time period within which you have committed to ship the order. In ISO 8601 date time format. Returned only for seller-fulfilled orders.  Note: LatestShipDate might not be returned for orders placed before February 1, 2013.  # noqa: E501

        :return: The latest_ship_date of this Order.  # noqa: E501
        :rtype: str
        """
        return self._latest_ship_date

    @latest_ship_date.setter
    def latest_ship_date(self, latest_ship_date):
        """Sets the latest_ship_date of this Order.

        The end of the time period within which you have committed to ship the order. In ISO 8601 date time format. Returned only for seller-fulfilled orders.  Note: LatestShipDate might not be returned for orders placed before February 1, 2013.  # noqa: E501

        :param latest_ship_date: The latest_ship_date of this Order.  # noqa: E501
        :type: str
        """

        self._latest_ship_date = latest_ship_date

    @property
    def earliest_delivery_date(self):
        """Gets the earliest_delivery_date of this Order.  # noqa: E501

        The start of the time period within which you have committed to fulfill the order. In ISO 8601 date time format. Returned only for seller-fulfilled orders.  # noqa: E501

        :return: The earliest_delivery_date of this Order.  # noqa: E501
        :rtype: str
        """
        return self._earliest_delivery_date

    @earliest_delivery_date.setter
    def earliest_delivery_date(self, earliest_delivery_date):
        """Sets the earliest_delivery_date of this Order.

        The start of the time period within which you have committed to fulfill the order. In ISO 8601 date time format. Returned only for seller-fulfilled orders.  # noqa: E501

        :param earliest_delivery_date: The earliest_delivery_date of this Order.  # noqa: E501
        :type: str
        """

        self._earliest_delivery_date = earliest_delivery_date

    @property
    def latest_delivery_date(self):
        """Gets the latest_delivery_date of this Order.  # noqa: E501

        The end of the time period within which you have committed to fulfill the order. In ISO 8601 date time format. Returned only for seller-fulfilled orders that do not have a PendingAvailability, Pending, or Canceled status.  # noqa: E501

        :return: The latest_delivery_date of this Order.  # noqa: E501
        :rtype: str
        """
        return self._latest_delivery_date

    @latest_delivery_date.setter
    def latest_delivery_date(self, latest_delivery_date):
        """Sets the latest_delivery_date of this Order.

        The end of the time period within which you have committed to fulfill the order. In ISO 8601 date time format. Returned only for seller-fulfilled orders that do not have a PendingAvailability, Pending, or Canceled status.  # noqa: E501

        :param latest_delivery_date: The latest_delivery_date of this Order.  # noqa: E501
        :type: str
        """

        self._latest_delivery_date = latest_delivery_date

    @property
    def is_business_order(self):
        """Gets the is_business_order of this Order.  # noqa: E501

        When true, the order is an Amazon Business order. An Amazon Business order is an order where the buyer is a Verified Business Buyer.  # noqa: E501

        :return: The is_business_order of this Order.  # noqa: E501
        :rtype: bool
        """
        return self._is_business_order

    @is_business_order.setter
    def is_business_order(self, is_business_order):
        """Sets the is_business_order of this Order.

        When true, the order is an Amazon Business order. An Amazon Business order is an order where the buyer is a Verified Business Buyer.  # noqa: E501

        :param is_business_order: The is_business_order of this Order.  # noqa: E501
        :type: bool
        """

        self._is_business_order = is_business_order

    @property
    def is_prime(self):
        """Gets the is_prime of this Order.  # noqa: E501

        When true, the order is a seller-fulfilled Amazon Prime order.  # noqa: E501

        :return: The is_prime of this Order.  # noqa: E501
        :rtype: bool
        """
        return self._is_prime

    @is_prime.setter
    def is_prime(self, is_prime):
        """Sets the is_prime of this Order.

        When true, the order is a seller-fulfilled Amazon Prime order.  # noqa: E501

        :param is_prime: The is_prime of this Order.  # noqa: E501
        :type: bool
        """

        self._is_prime = is_prime

    @property
    def is_premium_order(self):
        """Gets the is_premium_order of this Order.  # noqa: E501

        When true, the order has a Premium Shipping Service Level Agreement. For more information about Premium Shipping orders, see \"Premium Shipping Options\" in the Seller Central Help for your marketplace.  # noqa: E501

        :return: The is_premium_order of this Order.  # noqa: E501
        :rtype: bool
        """
        return self._is_premium_order

    @is_premium_order.setter
    def is_premium_order(self, is_premium_order):
        """Sets the is_premium_order of this Order.

        When true, the order has a Premium Shipping Service Level Agreement. For more information about Premium Shipping orders, see \"Premium Shipping Options\" in the Seller Central Help for your marketplace.  # noqa: E501

        :param is_premium_order: The is_premium_order of this Order.  # noqa: E501
        :type: bool
        """

        self._is_premium_order = is_premium_order

    @property
    def is_global_express_enabled(self):
        """Gets the is_global_express_enabled of this Order.  # noqa: E501

        When true, the order is a GlobalExpress order.  # noqa: E501

        :return: The is_global_express_enabled of this Order.  # noqa: E501
        :rtype: bool
        """
        return self._is_global_express_enabled

    @is_global_express_enabled.setter
    def is_global_express_enabled(self, is_global_express_enabled):
        """Sets the is_global_express_enabled of this Order.

        When true, the order is a GlobalExpress order.  # noqa: E501

        :param is_global_express_enabled: The is_global_express_enabled of this Order.  # noqa: E501
        :type: bool
        """

        self._is_global_express_enabled = is_global_express_enabled

    @property
    def replaced_order_id(self):
        """Gets the replaced_order_id of this Order.  # noqa: E501

        The order ID value for the order that is being replaced. Returned only if IsReplacementOrder = true.  # noqa: E501

        :return: The replaced_order_id of this Order.  # noqa: E501
        :rtype: str
        """
        return self._replaced_order_id

    @replaced_order_id.setter
    def replaced_order_id(self, replaced_order_id):
        """Sets the replaced_order_id of this Order.

        The order ID value for the order that is being replaced. Returned only if IsReplacementOrder = true.  # noqa: E501

        :param replaced_order_id: The replaced_order_id of this Order.  # noqa: E501
        :type: str
        """

        self._replaced_order_id = replaced_order_id

    @property
    def is_replacement_order(self):
        """Gets the is_replacement_order of this Order.  # noqa: E501

        When true, this is a replacement order.  # noqa: E501

        :return: The is_replacement_order of this Order.  # noqa: E501
        :rtype: bool
        """
        return self._is_replacement_order

    @is_replacement_order.setter
    def is_replacement_order(self, is_replacement_order):
        """Sets the is_replacement_order of this Order.

        When true, this is a replacement order.  # noqa: E501

        :param is_replacement_order: The is_replacement_order of this Order.  # noqa: E501
        :type: bool
        """

        self._is_replacement_order = is_replacement_order

    @property
    def promise_response_due_date(self):
        """Gets the promise_response_due_date of this Order.  # noqa: E501

        Indicates the date by which the seller must respond to the buyer with an estimated ship date. Returned only for Sourcing on Demand orders.  # noqa: E501

        :return: The promise_response_due_date of this Order.  # noqa: E501
        :rtype: str
        """
        return self._promise_response_due_date

    @promise_response_due_date.setter
    def promise_response_due_date(self, promise_response_due_date):
        """Sets the promise_response_due_date of this Order.

        Indicates the date by which the seller must respond to the buyer with an estimated ship date. Returned only for Sourcing on Demand orders.  # noqa: E501

        :param promise_response_due_date: The promise_response_due_date of this Order.  # noqa: E501
        :type: str
        """

        self._promise_response_due_date = promise_response_due_date

    @property
    def is_estimated_ship_date_set(self):
        """Gets the is_estimated_ship_date_set of this Order.  # noqa: E501

        When true, the estimated ship date is set for the order. Returned only for Sourcing on Demand orders.  # noqa: E501

        :return: The is_estimated_ship_date_set of this Order.  # noqa: E501
        :rtype: bool
        """
        return self._is_estimated_ship_date_set

    @is_estimated_ship_date_set.setter
    def is_estimated_ship_date_set(self, is_estimated_ship_date_set):
        """Sets the is_estimated_ship_date_set of this Order.

        When true, the estimated ship date is set for the order. Returned only for Sourcing on Demand orders.  # noqa: E501

        :param is_estimated_ship_date_set: The is_estimated_ship_date_set of this Order.  # noqa: E501
        :type: bool
        """

        self._is_estimated_ship_date_set = is_estimated_ship_date_set

    @property
    def is_sold_by_ab(self):
        """Gets the is_sold_by_ab of this Order.  # noqa: E501

        When true, the item within this order was bought and re-sold by Amazon Business EU SARL (ABEU). By buying and instantly re-selling your items, ABEU becomes the seller of record, making your inventory available for sale to customers who would not otherwise purchase from a third-party seller.  # noqa: E501

        :return: The is_sold_by_ab of this Order.  # noqa: E501
        :rtype: bool
        """
        return self._is_sold_by_ab

    @is_sold_by_ab.setter
    def is_sold_by_ab(self, is_sold_by_ab):
        """Sets the is_sold_by_ab of this Order.

        When true, the item within this order was bought and re-sold by Amazon Business EU SARL (ABEU). By buying and instantly re-selling your items, ABEU becomes the seller of record, making your inventory available for sale to customers who would not otherwise purchase from a third-party seller.  # noqa: E501

        :param is_sold_by_ab: The is_sold_by_ab of this Order.  # noqa: E501
        :type: bool
        """

        self._is_sold_by_ab = is_sold_by_ab

    @property
    def assigned_ship_from_location_address(self):
        """Gets the assigned_ship_from_location_address of this Order.  # noqa: E501


        :return: The assigned_ship_from_location_address of this Order.  # noqa: E501
        :rtype: Address
        """
        return self._assigned_ship_from_location_address

    @assigned_ship_from_location_address.setter
    def assigned_ship_from_location_address(self, assigned_ship_from_location_address):
        """Sets the assigned_ship_from_location_address of this Order.


        :param assigned_ship_from_location_address: The assigned_ship_from_location_address of this Order.  # noqa: E501
        :type: Address
        """

        self._assigned_ship_from_location_address = assigned_ship_from_location_address

    @property
    def fulfillment_instruction(self):
        """Gets the fulfillment_instruction of this Order.  # noqa: E501


        :return: The fulfillment_instruction of this Order.  # noqa: E501
        :rtype: FulfillmentInstruction
        """
        return self._fulfillment_instruction

    @fulfillment_instruction.setter
    def fulfillment_instruction(self, fulfillment_instruction):
        """Sets the fulfillment_instruction of this Order.


        :param fulfillment_instruction: The fulfillment_instruction of this Order.  # noqa: E501
        :type: FulfillmentInstruction
        """

        self._fulfillment_instruction = fulfillment_instruction

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Order, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Order):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Orders

    The Selling Partner API for Orders helps you programmatically retrieve order information. These APIs let you develop fast, flexible, custom applications in areas like order synchronization, order research, and demand-based decision support tools.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Money(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'currency_code': 'str',
        'amount': 'str'
    }

    attribute_map = {
        'currency_code': 'CurrencyCode',
        'amount': 'Amount'
    }

    def __init__(self, currency_code=None, amount=None):  # noqa: E501
        """Money - a model defined in Swagger"""  # noqa: E501
        self._currency_code = None
        self._amount = None
        self.discriminator = None
        if currency_code is not None:
            self.currency_code = currency_code
        if amount is not None:
            self.amount = amount

    @property
    def currency_code(self):
        """Gets the currency_code of this Money.  # noqa: E501

        The three-digit currency code. In ISO 4217 format.  # noqa: E501

        :return: The currency_code of this Money.  # noqa: E501
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """Sets the currency_code of this Money.

        The three-digit currency code. In ISO 4217 format.  # noqa: E501

        :param currency_code: The currency_code of this Money.  # noqa: E501
        :type: str
        """

        self._currency_code = currency_code

    @property
    def amount(self):
        """Gets the amount of this Money.  # noqa: E501

        The currency amount.  # noqa: E501

        :return: The amount of this Money.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this Money.

        The currency amount.  # noqa: E501

        :param amount: The amount of this Money.  # noqa: E501
        :type: str
        """

        self._amount = amount

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Money, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Money):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Orders

    The Selling Partner API for Orders helps you programmatically retrieve order information. These APIs let you develop fast, flexible, custom applications in areas like order synchronization, order research, and demand-based decision support tools.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class OrderItemBuyerInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'order_item_id': 'str',
        'buyer_customized_info': 'BuyerCustomizedInfoDetail',
        'gift_wrap_price': 'Money',
        'gift_wrap_tax': 'Money',
        'gift_message_text': 'str',
        'gift_wrap_level': 'str'
    }

    attribute_map = {
        'order_item_id': 'OrderItemId',
        'buyer_customized_info': 'BuyerCustomizedInfo',
        'gift_wrap_price': 'GiftWrapPrice',
        'gift_wrap_tax': 'GiftWrapTax',
        'gift_message_text': 'GiftMessageText',
        'gift_wrap_level': 'GiftWrapLevel'
    }

    def __init__(self, order_item_id=None, buyer_customized_info=None, gift_wrap_price=None, gift_wrap_tax=None, gift_message_text=None, gift_wrap_level=None):  # noqa: E501
        """OrderItemBuyerInfo - a model defined in Swagger"""  # noqa: E501
        self._order_item_id = None
        self._buyer_customized_info = None
        self._gift_wrap_price = None
        self._gift_wrap_tax = None
        self._gift_message_text = None
        self._gift_wrap_level = None
        self.discriminator = None
        self.order_item_id = order_item_id
        if buyer_customized_info is not None:
            self.buyer_customized_info = buyer_customized_info
        if gift_wrap_price is not None:
            self.gift_wrap_price = gift_wrap_price
        if gift_wrap_tax is not None:
            self.gift_wrap_tax = gift_wrap_tax
        if gift_message_text is not None:
            self.gift_message_text = gift_message_text
        if gift_wrap_level is not None:
            self.gift_wrap_level = gift_wrap_level

    @property
    def order_item_id(self):
        """Gets the order_item_id of this OrderItemBuyerInfo.  # noqa: E501

        An Amazon-defined order item identifier.  # noqa: E501

        :return: The order_item_id of this OrderItemBuyerInfo.  # noqa: E501
        :rtype: str
        """
        return self._order_item_id

    @order_item_id.setter
    def order_item_id(self, order_item_id):
        """Sets the order_item_id of this OrderItemBuyerInfo.

        An Amazon-defined order item identifier.  # noqa: E501

        :param order_item_id: The order_item_id of this OrderItemBuyerInfo.  # noqa: E501
        :type: str
        """
        if order_item_id is None:
            raise ValueError("Invalid value for `order_item_id`, must not be `None`")  # noqa: E501

        self._order_item_id = order_item_id

    @property
    def buyer_customized_info(self):
        """Gets the buyer_customized_info of this OrderItemBuyerInfo.  # noqa: E501


        :return: The buyer_customized_info of this OrderItemBuyerInfo.  # noqa: E501
        :rtype: BuyerCustomizedInfoDetail
        """
        return self._buyer_customized_info

    @buyer_customized_info.setter
    def buyer_customized_info(self, buyer_customized_info):
        """Sets the buyer_customized_info of this OrderItemBuyerInfo.


        :param buyer_customized_info: The buyer_customized_info of this OrderItemBuyerInfo.  # noqa: E501
        :type: BuyerCustomizedInfoDetail
        """

        self._buyer_customized_info = buyer_customized_info

    @property
    def gift_wrap_price(self):
        """Gets the gift_wrap_price of this OrderItemBuyerInfo.  # noqa: E501


        :return: The gift_wrap_price of this OrderItemBuyerInfo.  # noqa: E501
        :rtype: Money
        """
        return self._gift_wrap_price

    @gift_wrap_price.setter
    def gift_wrap_price(self, gift_wrap_price):
        """Sets the gift_wrap_price of this OrderItemBuyerInfo.


        :param gift_wrap_price: The gift_wrap_price of this OrderItemBuyerInfo.  # noqa: E501
        :type: Money
        """

        self._gift_wrap_price = gift_wrap_price

    @property
    def gift_wrap_tax(self):
        """Gets the gift_wrap_tax of this OrderItemBuyerInfo.  # noqa: E501


        :return: The gift_wrap_tax of this OrderItemBuyerInfo.  # noqa: E501
        :rtype: Money
        """
        return self._gift_wrap_tax

    @gift_wrap_tax.setter
    def gift_wrap_tax(self, gift_wrap_tax):
        """Sets the gift_wrap_tax of this OrderItemBuyerInfo.


        :param gift_wrap_tax: The gift_wrap_tax of this OrderItemBuyerInfo.  # noqa: E501
        :type: Money
        """

        self._gift_wrap_tax = gift_wrap_tax

    @property
    def gift_message_text(self):
        """Gets the gift_message_text of this OrderItemBuyerInfo.  # noqa: E501

        A gift message provided by the buyer.  # noqa: E501

        :return: The gift_message_text of this OrderItemBuyerInfo.  # noqa: E501
        :rtype: str
        """
        return self._gift_message_text

    @gift_message_text.setter
    def gift_message_text(self, gift_message_text):
        """Sets the gift_message_text of this OrderItemBuyerInfo.

        A gift message provided by the buyer.  # noqa: E501

        :param gift_message_text: The gift_message_text of this OrderItemBuyerInfo.  # noqa: E501
        :type: str
        """

        self._gift_message_text = gift_message_text

    @property
    def gift_wrap_level(self):
        """Gets the gift_wrap_level of this OrderItemBuyerInfo.  # noqa: E501

        The gift wrap level specified by the buyer.  # noqa: E501

        :return: The gift_wrap_level of this OrderItemBuyerInfo.  # noqa: E501
        :rtype: str
        """
        return self._gift_wrap_level

    @gift_wrap_level.setter
    def gift_wrap_level(self, gift_wrap_level):
        """Sets the gift_wrap_level of this OrderItemBuyerInfo.

        The gift wrap level specified by the buyer.  # noqa: E501

        :param gift_wrap_level: The gift_wrap_level of this OrderItemBuyerInfo.  # noqa: E501
        :type: str
        """

        self._gift_wrap_level = gift_wrap_level

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OrderItemBuyerInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrderItemBuyerInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Sellers

    The Selling Partner API for Sellers lets you retrieve information on behalf of sellers about their seller account, such as the marketplaces they participate in. Along with listing the marketplaces that a seller can sell in, the API also provides additional information about the marketplace such as the default language and the default currency. The API also provides seller-specific information such as whether the seller has suspended listings in that marketplace.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class GetMarketplaceParticipationsResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'payload': 'MarketplaceParticipationList',
        'errors': 'ErrorList'
    }

    attribute_map = {
        'payload': 'payload',
        'errors': 'errors'
    }

    def __init__(self, payload=None, errors=None):  # noqa: E501
        """GetMarketplaceParticipationsResponse - a model defined in Swagger"""  # noqa: E501
        self._payload = None
        self._errors = None
        self.discriminator = None
        if payload is not None:
            self.payload = payload
        if errors is not None:
            self.errors = errors

    @property
    def payload(self):
        """Gets the payload of this GetMarketplaceParticipationsResponse.  # noqa: E501


        :return: The payload of this GetMarketplaceParticipationsResponse.  # noqa: E501
        :rtype: MarketplaceParticipationList
        """
        return self._payload

    @payload.setter
    def payload(self, payload):
        """Sets the payload of this GetMarketplaceParticipationsResponse.


        :param payload: The payload of this GetMarketplaceParticipationsResponse.  # noqa: E501
        :type: MarketplaceParticipationList
        """

        self._payload = payload

    @property
    def errors(self):
        """Gets the errors of this GetMarketplaceParticipationsResponse.  # noqa: E501


        :return: The errors of this GetMarketplaceParticipationsResponse.  # noqa: E501
        :rtype: ErrorList
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """Sets the errors of this GetMarketplaceParticipationsResponse.


        :param errors: The errors of this GetMarketplaceParticipationsResponse.  # noqa: E501
        :type: ErrorList
        """

        self._errors = errors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetMarketplaceParticipationsResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetMarketplaceParticipationsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Notifications

    The Selling Partner API for Notifications lets you subscribe to notifications that are relevant to a selling partner's business. Using this API you can create a destination to receive notifications, subscribe to notifications, delete notification subscriptions, and more.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class EventBridgeResource(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'region': 'str',
        'account_id': 'str'
    }

    attribute_map = {
        'name': 'name',
        'region': 'region',
        'account_id': 'accountId'
    }

    def __init__(self, name=None, region=None, account_id=None):  # noqa: E501
        """EventBridgeResource - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._region = None
        self._account_id = None
        self.discriminator = None
        self.name = name
        self.region = region
        self.account_id = account_id

    @property
    def name(self):
        """Gets the name of this EventBridgeResource.  # noqa: E501

        The name of the partner event source associated with the destination.  # noqa: E501

        :return: The name of this EventBridgeResource.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this EventBridgeResource.

        The name of the partner event source associated with the destination.  # noqa: E501

        :param name: The name of this EventBridgeResource.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def region(self):
        """Gets the region of this EventBridgeResource.  # noqa: E501

        The AWS region in which you receive the notifications. For AWS regions that are supported in Amazon EventBridge, see https://docs.aws.amazon.com/general/latest/gr/ev.html.  # noqa: E501

        :return: The region of this EventBridgeResource.  # noqa: E501
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """Sets the region of this EventBridgeResource.

        The AWS region in which you receive the notifications. For AWS regions that are supported in Amazon EventBridge, see https://docs.aws.amazon.com/general/latest/gr/ev.html.  # noqa: E501

        :param region: The region of this EventBridgeResource.  # noqa: E501
        :type: str
        """
        if region is None:
            raise ValueError("Invalid value for `region`, must not be `None`")  # noqa: E501

        self._region = region

    @property
    def account_id(self):
        """Gets the account_id of this EventBridgeResource.  # noqa: E501

        The identifier for the AWS account that is responsible for charges related to receiving notifications.  # noqa: E501

        :return: The account_id of this EventBridgeResource.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this EventBridgeResource.

        The identifier for the AWS account that is responsible for charges related to receiving notifications.  # noqa: E501

        :param account_id: The account_id of this EventBridgeResource.  # noqa: E501
        :type: str
        """
        if account_id is None:
            raise ValueError("Invalid value for `account_id`, must not be `None`")  # noqa: E501

        self._account_id = account_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EventBridgeResource, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EventBridgeResource):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Orders

    The Selling Partner API for Orders helps you programmatically retrieve order information. These APIs let you develop fast, flexible, custom applications in areas like order synchronization, order research, and demand-based decision support tools.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class OrderBuyerInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amazon_order_id': 'str',
        'buyer_email': 'str',
        'buyer_name': 'str',
        'buyer_county': 'str',
        'buyer_tax_info': 'BuyerTaxInfo',
        'purchase_order_number': 'str'
    }

    attribute_map = {
        'amazon_order_id': 'AmazonOrderId',
        'buyer_email': 'BuyerEmail',
        'buyer_name': 'BuyerName',
        'buyer_county': 'BuyerCounty',
        'buyer_tax_info': 'BuyerTaxInfo',
        'purchase_order_number': 'PurchaseOrderNumber'
    }

    def __init__(self, amazon_order_id=None, buyer_email=None, buyer_name=None, buyer_county=None, buyer_tax_info=None, purchase_order_number=None):  # noqa: E501
        """OrderBuyerInfo - a model defined in Swagger"""  # noqa: E501
        self._amazon_order_id = None
        self._buyer_email = None
        self._buyer_name = None
        self._buyer_county = None
        self._buyer_tax_info = None
        self._purchase_order_number = None
        self.discriminator = None
        self.amazon_order_id = amazon_order_id
        if buyer_email is not None:
            self.buyer_email = buyer_email
        if buyer_name is not None:
            self.buyer_name = buyer_name
        if buyer_county is not None:
            self.buyer_county = buyer_county
        if buyer_tax_info is not None:
            self.buyer_tax_info = buyer_tax_info
        if purchase_order_number is not None:
            self.purchase_order_number = purchase_order_number

    @property
    def amazon_order_id(self):
        """Gets the amazon_order_id of this OrderBuyerInfo.  # noqa: E501

        An Amazon-defined order identifier, in 3-7-7 format.  # noqa: E501

        :return: The amazon_order_id of this OrderBuyerInfo.  # noqa: E501
        :rtype: str
        """
        return self._amazon_order_id

    @amazon_order_id.setter
    def amazon_order_id(self, amazon_order_id):
        """Sets the amazon_order_id of this OrderBuyerInfo.

        An Amazon-defined order identifier, in 3-7-7 format.  # noqa: E501

        :param amazon_order_id: The amazon_order_id of this OrderBuyerInfo.  # noqa: E501
        :type: str
        """
        if amazon_order_id is None:
            raise ValueError("Invalid value for `amazon_order_id`, must not be `None`")  # noqa: E501

        self._amazon_order_id = amazon_order_id

    @property
    def buyer_email(self):
        """Gets the buyer_email of this OrderBuyerInfo.  # noqa: E501

        The anonymized email address of the buyer.  # noqa: E501

        :return: The buyer_email of this OrderBuyerInfo.  # noqa: E501
        :rtype: str
        """
        return self._buyer_email

    @buyer_email.setter
    def buyer_email(self, buyer_email):
        """Sets the buyer_email of this OrderBuyerInfo.

        The anonymized email address of the buyer.  # noqa: E501

        :param buyer_email: The buyer_email of this OrderBuyerInfo.  # noqa: E501
        :type: str
        """

        self._buyer_email = buyer_email

    @property
    def buyer_name(self):
        """Gets the buyer_name of this OrderBuyerInfo.  # noqa: E501

        The name of the buyer.  # noqa: E501

        :return: The buyer_name of this OrderBuyerInfo.  # noqa: E501
        :rtype: str
        """
        return self._buyer_name

    @buyer_name.setter
    def buyer_name(self, buyer_name):
        """Sets the buyer_name of this OrderBuyerInfo.

        The name of the buyer.  # noqa: E501

        :param buyer_name: The buyer_name of this OrderBuyerInfo.  # noqa: E501
        :type: str
        """

        self._buyer_name = buyer_name

    @property
    def buyer_county(self):
        """Gets the buyer_county of this OrderBuyerInfo.  # noqa: E501

        The county of the buyer.  # noqa: E501

        :return: The buyer_county of this OrderBuyerInfo.  # noqa: E501
        :rtype: str
        """
        return self._buyer_county

    @buyer_county.setter
    def buyer_county(self, buyer_county):
        """Sets the buyer_county of this OrderBuyerInfo.

        The county of the buyer.  # noqa: E501

        :param buyer_county: The buyer_county of this OrderBuyerInfo.  # noqa: E501
        :type: str
        """

        self._buyer_county = buyer_county

    @property
    def buyer_tax_info(self):
        """Gets the buyer_tax_info of this OrderBuyerInfo.  # noqa: E501


        :return: The buyer_tax_info of this OrderBuyerInfo.  # noqa: E501
        :rtype: BuyerTaxInfo
        """
        return self._buyer_tax_info

    @buyer_tax_info.setter
    def buyer_tax_info(self, buyer_tax_info):
        """Sets the buyer_tax_info of this OrderBuyerInfo.


        :param buyer_tax_info: The buyer_tax_info of this OrderBuyerInfo.  # noqa: E501
        :type: BuyerTaxInfo
        """

        self._buyer_tax_info = buyer_tax_info

    @property
    def purchase_order_number(self):
        """Gets the purchase_order_number of this OrderBuyerInfo.  # noqa: E501

        The purchase order (PO) number entered by the buyer at checkout. Returned only for orders where the buyer entered a PO number at checkout.  # noqa: E501

        :return: The purchase_order_number of this OrderBuyerInfo.  # noqa: E501
        :rtype: str
        """
        return self._purchase_order_number

    @purchase_order_number.setter
    def purchase_order_number(self, purchase_order_number):
        """Sets the purchase_order_number of this OrderBuyerInfo.

        The purchase order (PO) number entered by the buyer at checkout. Returned only for orders where the buyer entered a PO number at checkout.  # noqa: E501

        :param purchase_order_number: The purchase_order_number of this OrderBuyerInfo.  # noqa: E501
        :type: str
        """

        self._purchase_order_number = purchase_order_number

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OrderBuyerInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrderBuyerInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



def fill_query_params(query, *args):
    return query.format(*args)


def sp_endpoint(path, method='GET'):
    def decorator(function):
        def wrapper(*args, **kwargs):
            kwargs.update({
                'path': path,
                'method': method
            })
            return function(*args, **kwargs)
        return wrapper
    return decorator



# coding: utf-8

"""
    Selling Partner API for Product Fees

    The Selling Partner API for Product Fees lets you programmatically retrieve estimated fees for a product. You can then account for those fees in your pricing.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class FeesEstimateResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'status': 'str',
        'fees_estimate_identifier': 'FeesEstimateIdentifier',
        'fees_estimate': 'FeesEstimate',
        'error': 'FeesEstimateError'
    }

    attribute_map = {
        'status': 'Status',
        'fees_estimate_identifier': 'FeesEstimateIdentifier',
        'fees_estimate': 'FeesEstimate',
        'error': 'Error'
    }

    def __init__(self, status=None, fees_estimate_identifier=None, fees_estimate=None, error=None):  # noqa: E501
        """FeesEstimateResult - a model defined in Swagger"""  # noqa: E501
        self._status = None
        self._fees_estimate_identifier = None
        self._fees_estimate = None
        self._error = None
        self.discriminator = None
        if status is not None:
            self.status = status
        if fees_estimate_identifier is not None:
            self.fees_estimate_identifier = fees_estimate_identifier
        if fees_estimate is not None:
            self.fees_estimate = fees_estimate
        if error is not None:
            self.error = error

    @property
    def status(self):
        """Gets the status of this FeesEstimateResult.  # noqa: E501

        The status of the fee request. Possible values: Success, ClientError, ServiceError.  # noqa: E501

        :return: The status of this FeesEstimateResult.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this FeesEstimateResult.

        The status of the fee request. Possible values: Success, ClientError, ServiceError.  # noqa: E501

        :param status: The status of this FeesEstimateResult.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def fees_estimate_identifier(self):
        """Gets the fees_estimate_identifier of this FeesEstimateResult.  # noqa: E501


        :return: The fees_estimate_identifier of this FeesEstimateResult.  # noqa: E501
        :rtype: FeesEstimateIdentifier
        """
        return self._fees_estimate_identifier

    @fees_estimate_identifier.setter
    def fees_estimate_identifier(self, fees_estimate_identifier):
        """Sets the fees_estimate_identifier of this FeesEstimateResult.


        :param fees_estimate_identifier: The fees_estimate_identifier of this FeesEstimateResult.  # noqa: E501
        :type: FeesEstimateIdentifier
        """

        self._fees_estimate_identifier = fees_estimate_identifier

    @property
    def fees_estimate(self):
        """Gets the fees_estimate of this FeesEstimateResult.  # noqa: E501


        :return: The fees_estimate of this FeesEstimateResult.  # noqa: E501
        :rtype: FeesEstimate
        """
        return self._fees_estimate

    @fees_estimate.setter
    def fees_estimate(self, fees_estimate):
        """Sets the fees_estimate of this FeesEstimateResult.


        :param fees_estimate: The fees_estimate of this FeesEstimateResult.  # noqa: E501
        :type: FeesEstimate
        """

        self._fees_estimate = fees_estimate

    @property
    def error(self):
        """Gets the error of this FeesEstimateResult.  # noqa: E501


        :return: The error of this FeesEstimateResult.  # noqa: E501
        :rtype: FeesEstimateError
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this FeesEstimateResult.


        :param error: The error of this FeesEstimateResult.  # noqa: E501
        :type: FeesEstimateError
        """

        self._error = error

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FeesEstimateResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FeesEstimateResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Orders

    The Selling Partner API for Orders helps you programmatically retrieve order information. These APIs let you develop fast, flexible, custom applications in areas like order synchronization, order research, and demand-based decision support tools.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class OrderItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'asin': 'str',
        'seller_sku': 'str',
        'order_item_id': 'str',
        'title': 'str',
        'quantity_ordered': 'int',
        'quantity_shipped': 'int',
        'product_info': 'ProductInfoDetail',
        'points_granted': 'PointsGrantedDetail',
        'item_price': 'Money',
        'shipping_price': 'Money',
        'item_tax': 'Money',
        'shipping_tax': 'Money',
        'shipping_discount': 'Money',
        'shipping_discount_tax': 'Money',
        'promotion_discount': 'Money',
        'promotion_discount_tax': 'Money',
        'promotion_ids': 'PromotionIdList',
        'cod_fee': 'Money',
        'cod_fee_discount': 'Money',
        'is_gift': 'bool',
        'condition_note': 'str',
        'condition_id': 'str',
        'condition_subtype_id': 'str',
        'scheduled_delivery_start_date': 'str',
        'scheduled_delivery_end_date': 'str',
        'price_designation': 'str',
        'tax_collection': 'TaxCollection',
        'serial_number_required': 'bool',
        'is_transparency': 'bool',
        'ioss_number': 'str',
        'deemed_reseller_category': 'str'
    }

    attribute_map = {
        'asin': 'ASIN',
        'seller_sku': 'SellerSKU',
        'order_item_id': 'OrderItemId',
        'title': 'Title',
        'quantity_ordered': 'QuantityOrdered',
        'quantity_shipped': 'QuantityShipped',
        'product_info': 'ProductInfo',
        'points_granted': 'PointsGranted',
        'item_price': 'ItemPrice',
        'shipping_price': 'ShippingPrice',
        'item_tax': 'ItemTax',
        'shipping_tax': 'ShippingTax',
        'shipping_discount': 'ShippingDiscount',
        'shipping_discount_tax': 'ShippingDiscountTax',
        'promotion_discount': 'PromotionDiscount',
        'promotion_discount_tax': 'PromotionDiscountTax',
        'promotion_ids': 'PromotionIds',
        'cod_fee': 'CODFee',
        'cod_fee_discount': 'CODFeeDiscount',
        'is_gift': 'IsGift',
        'condition_note': 'ConditionNote',
        'condition_id': 'ConditionId',
        'condition_subtype_id': 'ConditionSubtypeId',
        'scheduled_delivery_start_date': 'ScheduledDeliveryStartDate',
        'scheduled_delivery_end_date': 'ScheduledDeliveryEndDate',
        'price_designation': 'PriceDesignation',
        'tax_collection': 'TaxCollection',
        'serial_number_required': 'SerialNumberRequired',
        'is_transparency': 'IsTransparency',
        'ioss_number': 'IossNumber',
        'deemed_reseller_category': 'DeemedResellerCategory'
    }

    def __init__(self, asin=None, seller_sku=None, order_item_id=None, title=None, quantity_ordered=None, quantity_shipped=None, product_info=None, points_granted=None, item_price=None, shipping_price=None, item_tax=None, shipping_tax=None, shipping_discount=None, shipping_discount_tax=None, promotion_discount=None, promotion_discount_tax=None, promotion_ids=None, cod_fee=None, cod_fee_discount=None, is_gift=None, condition_note=None, condition_id=None, condition_subtype_id=None, scheduled_delivery_start_date=None, scheduled_delivery_end_date=None, price_designation=None, tax_collection=None, serial_number_required=None, is_transparency=None, ioss_number=None, deemed_reseller_category=None):  # noqa: E501
        """OrderItem - a model defined in Swagger"""  # noqa: E501
        self._asin = None
        self._seller_sku = None
        self._order_item_id = None
        self._title = None
        self._quantity_ordered = None
        self._quantity_shipped = None
        self._product_info = None
        self._points_granted = None
        self._item_price = None
        self._shipping_price = None
        self._item_tax = None
        self._shipping_tax = None
        self._shipping_discount = None
        self._shipping_discount_tax = None
        self._promotion_discount = None
        self._promotion_discount_tax = None
        self._promotion_ids = None
        self._cod_fee = None
        self._cod_fee_discount = None
        self._is_gift = None
        self._condition_note = None
        self._condition_id = None
        self._condition_subtype_id = None
        self._scheduled_delivery_start_date = None
        self._scheduled_delivery_end_date = None
        self._price_designation = None
        self._tax_collection = None
        self._serial_number_required = None
        self._is_transparency = None
        self._ioss_number = None
        self._deemed_reseller_category = None
        self.discriminator = None
        self.asin = asin
        if seller_sku is not None:
            self.seller_sku = seller_sku
        self.order_item_id = order_item_id
        if title is not None:
            self.title = title
        self.quantity_ordered = quantity_ordered
        if quantity_shipped is not None:
            self.quantity_shipped = quantity_shipped
        if product_info is not None:
            self.product_info = product_info
        if points_granted is not None:
            self.points_granted = points_granted
        if item_price is not None:
            self.item_price = item_price
        if shipping_price is not None:
            self.shipping_price = shipping_price
        if item_tax is not None:
            self.item_tax = item_tax
        if shipping_tax is not None:
            self.shipping_tax = shipping_tax
        if shipping_discount is not None:
            self.shipping_discount = shipping_discount
        if shipping_discount_tax is not None:
            self.shipping_discount_tax = shipping_discount_tax
        if promotion_discount is not None:
            self.promotion_discount = promotion_discount
        if promotion_discount_tax is not None:
            self.promotion_discount_tax = promotion_discount_tax
        if promotion_ids is not None:
            self.promotion_ids = promotion_ids
        if cod_fee is not None:
            self.cod_fee = cod_fee
        if cod_fee_discount is not None:
            self.cod_fee_discount = cod_fee_discount
        if is_gift is not None:
            self.is_gift = is_gift
        if condition_note is not None:
            self.condition_note = condition_note
        if condition_id is not None:
            self.condition_id = condition_id
        if condition_subtype_id is not None:
            self.condition_subtype_id = condition_subtype_id
        if scheduled_delivery_start_date is not None:
            self.scheduled_delivery_start_date = scheduled_delivery_start_date
        if scheduled_delivery_end_date is not None:
            self.scheduled_delivery_end_date = scheduled_delivery_end_date
        if price_designation is not None:
            self.price_designation = price_designation
        if tax_collection is not None:
            self.tax_collection = tax_collection
        if serial_number_required is not None:
            self.serial_number_required = serial_number_required
        if is_transparency is not None:
            self.is_transparency = is_transparency
        if ioss_number is not None:
            self.ioss_number = ioss_number
        if deemed_reseller_category is not None:
            self.deemed_reseller_category = deemed_reseller_category

    @property
    def asin(self):
        """Gets the asin of this OrderItem.  # noqa: E501

        The Amazon Standard Identification Number (ASIN) of the item.  # noqa: E501

        :return: The asin of this OrderItem.  # noqa: E501
        :rtype: str
        """
        return self._asin

    @asin.setter
    def asin(self, asin):
        """Sets the asin of this OrderItem.

        The Amazon Standard Identification Number (ASIN) of the item.  # noqa: E501

        :param asin: The asin of this OrderItem.  # noqa: E501
        :type: str
        """
        if asin is None:
            raise ValueError("Invalid value for `asin`, must not be `None`")  # noqa: E501

        self._asin = asin

    @property
    def seller_sku(self):
        """Gets the seller_sku of this OrderItem.  # noqa: E501

        The seller stock keeping unit (SKU) of the item.  # noqa: E501

        :return: The seller_sku of this OrderItem.  # noqa: E501
        :rtype: str
        """
        return self._seller_sku

    @seller_sku.setter
    def seller_sku(self, seller_sku):
        """Sets the seller_sku of this OrderItem.

        The seller stock keeping unit (SKU) of the item.  # noqa: E501

        :param seller_sku: The seller_sku of this OrderItem.  # noqa: E501
        :type: str
        """

        self._seller_sku = seller_sku

    @property
    def order_item_id(self):
        """Gets the order_item_id of this OrderItem.  # noqa: E501

        An Amazon-defined order item identifier.  # noqa: E501

        :return: The order_item_id of this OrderItem.  # noqa: E501
        :rtype: str
        """
        return self._order_item_id

    @order_item_id.setter
    def order_item_id(self, order_item_id):
        """Sets the order_item_id of this OrderItem.

        An Amazon-defined order item identifier.  # noqa: E501

        :param order_item_id: The order_item_id of this OrderItem.  # noqa: E501
        :type: str
        """
        if order_item_id is None:
            raise ValueError("Invalid value for `order_item_id`, must not be `None`")  # noqa: E501

        self._order_item_id = order_item_id

    @property
    def title(self):
        """Gets the title of this OrderItem.  # noqa: E501

        The name of the item.  # noqa: E501

        :return: The title of this OrderItem.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this OrderItem.

        The name of the item.  # noqa: E501

        :param title: The title of this OrderItem.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def quantity_ordered(self):
        """Gets the quantity_ordered of this OrderItem.  # noqa: E501

        The number of items in the order.   # noqa: E501

        :return: The quantity_ordered of this OrderItem.  # noqa: E501
        :rtype: int
        """
        return self._quantity_ordered

    @quantity_ordered.setter
    def quantity_ordered(self, quantity_ordered):
        """Sets the quantity_ordered of this OrderItem.

        The number of items in the order.   # noqa: E501

        :param quantity_ordered: The quantity_ordered of this OrderItem.  # noqa: E501
        :type: int
        """
        if quantity_ordered is None:
            raise ValueError("Invalid value for `quantity_ordered`, must not be `None`")  # noqa: E501

        self._quantity_ordered = quantity_ordered

    @property
    def quantity_shipped(self):
        """Gets the quantity_shipped of this OrderItem.  # noqa: E501

        The number of items shipped.  # noqa: E501

        :return: The quantity_shipped of this OrderItem.  # noqa: E501
        :rtype: int
        """
        return self._quantity_shipped

    @quantity_shipped.setter
    def quantity_shipped(self, quantity_shipped):
        """Sets the quantity_shipped of this OrderItem.

        The number of items shipped.  # noqa: E501

        :param quantity_shipped: The quantity_shipped of this OrderItem.  # noqa: E501
        :type: int
        """

        self._quantity_shipped = quantity_shipped

    @property
    def product_info(self):
        """Gets the product_info of this OrderItem.  # noqa: E501


        :return: The product_info of this OrderItem.  # noqa: E501
        :rtype: ProductInfoDetail
        """
        return self._product_info

    @product_info.setter
    def product_info(self, product_info):
        """Sets the product_info of this OrderItem.


        :param product_info: The product_info of this OrderItem.  # noqa: E501
        :type: ProductInfoDetail
        """

        self._product_info = product_info

    @property
    def points_granted(self):
        """Gets the points_granted of this OrderItem.  # noqa: E501


        :return: The points_granted of this OrderItem.  # noqa: E501
        :rtype: PointsGrantedDetail
        """
        return self._points_granted

    @points_granted.setter
    def points_granted(self, points_granted):
        """Sets the points_granted of this OrderItem.


        :param points_granted: The points_granted of this OrderItem.  # noqa: E501
        :type: PointsGrantedDetail
        """

        self._points_granted = points_granted

    @property
    def item_price(self):
        """Gets the item_price of this OrderItem.  # noqa: E501


        :return: The item_price of this OrderItem.  # noqa: E501
        :rtype: Money
        """
        return self._item_price

    @item_price.setter
    def item_price(self, item_price):
        """Sets the item_price of this OrderItem.


        :param item_price: The item_price of this OrderItem.  # noqa: E501
        :type: Money
        """

        self._item_price = item_price

    @property
    def shipping_price(self):
        """Gets the shipping_price of this OrderItem.  # noqa: E501


        :return: The shipping_price of this OrderItem.  # noqa: E501
        :rtype: Money
        """
        return self._shipping_price

    @shipping_price.setter
    def shipping_price(self, shipping_price):
        """Sets the shipping_price of this OrderItem.


        :param shipping_price: The shipping_price of this OrderItem.  # noqa: E501
        :type: Money
        """

        self._shipping_price = shipping_price

    @property
    def item_tax(self):
        """Gets the item_tax of this OrderItem.  # noqa: E501


        :return: The item_tax of this OrderItem.  # noqa: E501
        :rtype: Money
        """
        return self._item_tax

    @item_tax.setter
    def item_tax(self, item_tax):
        """Sets the item_tax of this OrderItem.


        :param item_tax: The item_tax of this OrderItem.  # noqa: E501
        :type: Money
        """

        self._item_tax = item_tax

    @property
    def shipping_tax(self):
        """Gets the shipping_tax of this OrderItem.  # noqa: E501


        :return: The shipping_tax of this OrderItem.  # noqa: E501
        :rtype: Money
        """
        return self._shipping_tax

    @shipping_tax.setter
    def shipping_tax(self, shipping_tax):
        """Sets the shipping_tax of this OrderItem.


        :param shipping_tax: The shipping_tax of this OrderItem.  # noqa: E501
        :type: Money
        """

        self._shipping_tax = shipping_tax

    @property
    def shipping_discount(self):
        """Gets the shipping_discount of this OrderItem.  # noqa: E501


        :return: The shipping_discount of this OrderItem.  # noqa: E501
        :rtype: Money
        """
        return self._shipping_discount

    @shipping_discount.setter
    def shipping_discount(self, shipping_discount):
        """Sets the shipping_discount of this OrderItem.


        :param shipping_discount: The shipping_discount of this OrderItem.  # noqa: E501
        :type: Money
        """

        self._shipping_discount = shipping_discount

    @property
    def shipping_discount_tax(self):
        """Gets the shipping_discount_tax of this OrderItem.  # noqa: E501


        :return: The shipping_discount_tax of this OrderItem.  # noqa: E501
        :rtype: Money
        """
        return self._shipping_discount_tax

    @shipping_discount_tax.setter
    def shipping_discount_tax(self, shipping_discount_tax):
        """Sets the shipping_discount_tax of this OrderItem.


        :param shipping_discount_tax: The shipping_discount_tax of this OrderItem.  # noqa: E501
        :type: Money
        """

        self._shipping_discount_tax = shipping_discount_tax

    @property
    def promotion_discount(self):
        """Gets the promotion_discount of this OrderItem.  # noqa: E501


        :return: The promotion_discount of this OrderItem.  # noqa: E501
        :rtype: Money
        """
        return self._promotion_discount

    @promotion_discount.setter
    def promotion_discount(self, promotion_discount):
        """Sets the promotion_discount of this OrderItem.


        :param promotion_discount: The promotion_discount of this OrderItem.  # noqa: E501
        :type: Money
        """

        self._promotion_discount = promotion_discount

    @property
    def promotion_discount_tax(self):
        """Gets the promotion_discount_tax of this OrderItem.  # noqa: E501


        :return: The promotion_discount_tax of this OrderItem.  # noqa: E501
        :rtype: Money
        """
        return self._promotion_discount_tax

    @promotion_discount_tax.setter
    def promotion_discount_tax(self, promotion_discount_tax):
        """Sets the promotion_discount_tax of this OrderItem.


        :param promotion_discount_tax: The promotion_discount_tax of this OrderItem.  # noqa: E501
        :type: Money
        """

        self._promotion_discount_tax = promotion_discount_tax

    @property
    def promotion_ids(self):
        """Gets the promotion_ids of this OrderItem.  # noqa: E501


        :return: The promotion_ids of this OrderItem.  # noqa: E501
        :rtype: PromotionIdList
        """
        return self._promotion_ids

    @promotion_ids.setter
    def promotion_ids(self, promotion_ids):
        """Sets the promotion_ids of this OrderItem.


        :param promotion_ids: The promotion_ids of this OrderItem.  # noqa: E501
        :type: PromotionIdList
        """

        self._promotion_ids = promotion_ids

    @property
    def cod_fee(self):
        """Gets the cod_fee of this OrderItem.  # noqa: E501


        :return: The cod_fee of this OrderItem.  # noqa: E501
        :rtype: Money
        """
        return self._cod_fee

    @cod_fee.setter
    def cod_fee(self, cod_fee):
        """Sets the cod_fee of this OrderItem.


        :param cod_fee: The cod_fee of this OrderItem.  # noqa: E501
        :type: Money
        """

        self._cod_fee = cod_fee

    @property
    def cod_fee_discount(self):
        """Gets the cod_fee_discount of this OrderItem.  # noqa: E501


        :return: The cod_fee_discount of this OrderItem.  # noqa: E501
        :rtype: Money
        """
        return self._cod_fee_discount

    @cod_fee_discount.setter
    def cod_fee_discount(self, cod_fee_discount):
        """Sets the cod_fee_discount of this OrderItem.


        :param cod_fee_discount: The cod_fee_discount of this OrderItem.  # noqa: E501
        :type: Money
        """

        self._cod_fee_discount = cod_fee_discount

    @property
    def is_gift(self):
        """Gets the is_gift of this OrderItem.  # noqa: E501

        When true, the item is a gift.  # noqa: E501

        :return: The is_gift of this OrderItem.  # noqa: E501
        :rtype: bool
        """
        return self._is_gift

    @is_gift.setter
    def is_gift(self, is_gift):
        """Sets the is_gift of this OrderItem.

        When true, the item is a gift.  # noqa: E501

        :param is_gift: The is_gift of this OrderItem.  # noqa: E501
        :type: bool
        """

        self._is_gift = is_gift

    @property
    def condition_note(self):
        """Gets the condition_note of this OrderItem.  # noqa: E501

        The condition of the item as described by the seller.  # noqa: E501

        :return: The condition_note of this OrderItem.  # noqa: E501
        :rtype: str
        """
        return self._condition_note

    @condition_note.setter
    def condition_note(self, condition_note):
        """Sets the condition_note of this OrderItem.

        The condition of the item as described by the seller.  # noqa: E501

        :param condition_note: The condition_note of this OrderItem.  # noqa: E501
        :type: str
        """

        self._condition_note = condition_note

    @property
    def condition_id(self):
        """Gets the condition_id of this OrderItem.  # noqa: E501

        The condition of the item.  Possible values: New, Used, Collectible, Refurbished, Preorder, Club.  # noqa: E501

        :return: The condition_id of this OrderItem.  # noqa: E501
        :rtype: str
        """
        return self._condition_id

    @condition_id.setter
    def condition_id(self, condition_id):
        """Sets the condition_id of this OrderItem.

        The condition of the item.  Possible values: New, Used, Collectible, Refurbished, Preorder, Club.  # noqa: E501

        :param condition_id: The condition_id of this OrderItem.  # noqa: E501
        :type: str
        """

        self._condition_id = condition_id

    @property
    def condition_subtype_id(self):
        """Gets the condition_subtype_id of this OrderItem.  # noqa: E501

        The subcondition of the item.  Possible values: New, Mint, Very Good, Good, Acceptable, Poor, Club, OEM, Warranty, Refurbished Warranty, Refurbished, Open Box, Any, Other.  # noqa: E501

        :return: The condition_subtype_id of this OrderItem.  # noqa: E501
        :rtype: str
        """
        return self._condition_subtype_id

    @condition_subtype_id.setter
    def condition_subtype_id(self, condition_subtype_id):
        """Sets the condition_subtype_id of this OrderItem.

        The subcondition of the item.  Possible values: New, Mint, Very Good, Good, Acceptable, Poor, Club, OEM, Warranty, Refurbished Warranty, Refurbished, Open Box, Any, Other.  # noqa: E501

        :param condition_subtype_id: The condition_subtype_id of this OrderItem.  # noqa: E501
        :type: str
        """

        self._condition_subtype_id = condition_subtype_id

    @property
    def scheduled_delivery_start_date(self):
        """Gets the scheduled_delivery_start_date of this OrderItem.  # noqa: E501

        The start date of the scheduled delivery window in the time zone of the order destination. In ISO 8601 date time format.  # noqa: E501

        :return: The scheduled_delivery_start_date of this OrderItem.  # noqa: E501
        :rtype: str
        """
        return self._scheduled_delivery_start_date

    @scheduled_delivery_start_date.setter
    def scheduled_delivery_start_date(self, scheduled_delivery_start_date):
        """Sets the scheduled_delivery_start_date of this OrderItem.

        The start date of the scheduled delivery window in the time zone of the order destination. In ISO 8601 date time format.  # noqa: E501

        :param scheduled_delivery_start_date: The scheduled_delivery_start_date of this OrderItem.  # noqa: E501
        :type: str
        """

        self._scheduled_delivery_start_date = scheduled_delivery_start_date

    @property
    def scheduled_delivery_end_date(self):
        """Gets the scheduled_delivery_end_date of this OrderItem.  # noqa: E501

        The end date of the scheduled delivery window in the time zone of the order destination. In ISO 8601 date time format.  # noqa: E501

        :return: The scheduled_delivery_end_date of this OrderItem.  # noqa: E501
        :rtype: str
        """
        return self._scheduled_delivery_end_date

    @scheduled_delivery_end_date.setter
    def scheduled_delivery_end_date(self, scheduled_delivery_end_date):
        """Sets the scheduled_delivery_end_date of this OrderItem.

        The end date of the scheduled delivery window in the time zone of the order destination. In ISO 8601 date time format.  # noqa: E501

        :param scheduled_delivery_end_date: The scheduled_delivery_end_date of this OrderItem.  # noqa: E501
        :type: str
        """

        self._scheduled_delivery_end_date = scheduled_delivery_end_date

    @property
    def price_designation(self):
        """Gets the price_designation of this OrderItem.  # noqa: E501

        Indicates that the selling price is a special price that is available only for Amazon Business orders. For more information about the Amazon Business Seller Program, see the [Amazon Business website](https://www.amazon.com/b2b/info/amazon-business).   Possible values: BusinessPrice - A special price that is available only for Amazon Business orders.  # noqa: E501

        :return: The price_designation of this OrderItem.  # noqa: E501
        :rtype: str
        """
        return self._price_designation

    @price_designation.setter
    def price_designation(self, price_designation):
        """Sets the price_designation of this OrderItem.

        Indicates that the selling price is a special price that is available only for Amazon Business orders. For more information about the Amazon Business Seller Program, see the [Amazon Business website](https://www.amazon.com/b2b/info/amazon-business).   Possible values: BusinessPrice - A special price that is available only for Amazon Business orders.  # noqa: E501

        :param price_designation: The price_designation of this OrderItem.  # noqa: E501
        :type: str
        """

        self._price_designation = price_designation

    @property
    def tax_collection(self):
        """Gets the tax_collection of this OrderItem.  # noqa: E501


        :return: The tax_collection of this OrderItem.  # noqa: E501
        :rtype: TaxCollection
        """
        return self._tax_collection

    @tax_collection.setter
    def tax_collection(self, tax_collection):
        """Sets the tax_collection of this OrderItem.


        :param tax_collection: The tax_collection of this OrderItem.  # noqa: E501
        :type: TaxCollection
        """

        self._tax_collection = tax_collection

    @property
    def serial_number_required(self):
        """Gets the serial_number_required of this OrderItem.  # noqa: E501

        When true, the product type for this item has a serial number.  Returned only for Amazon Easy Ship orders.  # noqa: E501

        :return: The serial_number_required of this OrderItem.  # noqa: E501
        :rtype: bool
        """
        return self._serial_number_required

    @serial_number_required.setter
    def serial_number_required(self, serial_number_required):
        """Sets the serial_number_required of this OrderItem.

        When true, the product type for this item has a serial number.  Returned only for Amazon Easy Ship orders.  # noqa: E501

        :param serial_number_required: The serial_number_required of this OrderItem.  # noqa: E501
        :type: bool
        """

        self._serial_number_required = serial_number_required

    @property
    def is_transparency(self):
        """Gets the is_transparency of this OrderItem.  # noqa: E501

        When true, transparency codes are required.  # noqa: E501

        :return: The is_transparency of this OrderItem.  # noqa: E501
        :rtype: bool
        """
        return self._is_transparency

    @is_transparency.setter
    def is_transparency(self, is_transparency):
        """Sets the is_transparency of this OrderItem.

        When true, transparency codes are required.  # noqa: E501

        :param is_transparency: The is_transparency of this OrderItem.  # noqa: E501
        :type: bool
        """

        self._is_transparency = is_transparency

    @property
    def ioss_number(self):
        """Gets the ioss_number of this OrderItem.  # noqa: E501

        The IOSS number of the seller. Sellers selling in the EU will be assigned a unique IOSS number that must be listed on all packages sent to the EU.  # noqa: E501

        :return: The ioss_number of this OrderItem.  # noqa: E501
        :rtype: str
        """
        return self._ioss_number

    @ioss_number.setter
    def ioss_number(self, ioss_number):
        """Sets the ioss_number of this OrderItem.

        The IOSS number of the seller. Sellers selling in the EU will be assigned a unique IOSS number that must be listed on all packages sent to the EU.  # noqa: E501

        :param ioss_number: The ioss_number of this OrderItem.  # noqa: E501
        :type: str
        """

        self._ioss_number = ioss_number

    @property
    def deemed_reseller_category(self):
        """Gets the deemed_reseller_category of this OrderItem.  # noqa: E501

        The category of deemed reseller. This applies to selling partners that are not based in the EU and is used to help them meet the VAT Deemed Reseller tax laws in the EU and UK.  # noqa: E501

        :return: The deemed_reseller_category of this OrderItem.  # noqa: E501
        :rtype: str
        """
        return self._deemed_reseller_category

    @deemed_reseller_category.setter
    def deemed_reseller_category(self, deemed_reseller_category):
        """Sets the deemed_reseller_category of this OrderItem.

        The category of deemed reseller. This applies to selling partners that are not based in the EU and is used to help them meet the VAT Deemed Reseller tax laws in the EU and UK.  # noqa: E501

        :param deemed_reseller_category: The deemed_reseller_category of this OrderItem.  # noqa: E501
        :type: str
        """
        allowed_values = ["IOSS", "UOSS"]  # noqa: E501
        if deemed_reseller_category not in allowed_values:
            raise ValueError(
                "Invalid value for `deemed_reseller_category` ({0}), must be one of {1}"  # noqa: E501
                .format(deemed_reseller_category, allowed_values)
            )

        self._deemed_reseller_category = deemed_reseller_category

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OrderItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrderItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Pricing

    The Selling Partner API for Pricing helps you programmatically retrieve product pricing and offer information for Amazon Marketplace products.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class DetailedShippingTimeType(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'minimum_hours': 'int',
        'maximum_hours': 'int',
        'available_date': 'float',
        'availability_type': 'str'
    }

    attribute_map = {
        'minimum_hours': 'minimumHours',
        'maximum_hours': 'maximumHours',
        'available_date': 'availableDate',
        'availability_type': 'availabilityType'
    }

    def __init__(self, minimum_hours=None, maximum_hours=None, available_date=None, availability_type=None):  # noqa: E501
        """DetailedShippingTimeType - a model defined in Swagger"""  # noqa: E501
        self._minimum_hours = None
        self._maximum_hours = None
        self._available_date = None
        self._availability_type = None
        self.discriminator = None
        if minimum_hours is not None:
            self.minimum_hours = minimum_hours
        if maximum_hours is not None:
            self.maximum_hours = maximum_hours
        if available_date is not None:
            self.available_date = available_date
        if availability_type is not None:
            self.availability_type = availability_type

    @property
    def minimum_hours(self):
        """Gets the minimum_hours of this DetailedShippingTimeType.  # noqa: E501

        The minimum time, in hours, that the item will likely be shipped after the order has been placed.  # noqa: E501

        :return: The minimum_hours of this DetailedShippingTimeType.  # noqa: E501
        :rtype: int
        """
        return self._minimum_hours

    @minimum_hours.setter
    def minimum_hours(self, minimum_hours):
        """Sets the minimum_hours of this DetailedShippingTimeType.

        The minimum time, in hours, that the item will likely be shipped after the order has been placed.  # noqa: E501

        :param minimum_hours: The minimum_hours of this DetailedShippingTimeType.  # noqa: E501
        :type: int
        """

        self._minimum_hours = minimum_hours

    @property
    def maximum_hours(self):
        """Gets the maximum_hours of this DetailedShippingTimeType.  # noqa: E501

        The maximum time, in hours, that the item will likely be shipped after the order has been placed.  # noqa: E501

        :return: The maximum_hours of this DetailedShippingTimeType.  # noqa: E501
        :rtype: int
        """
        return self._maximum_hours

    @maximum_hours.setter
    def maximum_hours(self, maximum_hours):
        """Sets the maximum_hours of this DetailedShippingTimeType.

        The maximum time, in hours, that the item will likely be shipped after the order has been placed.  # noqa: E501

        :param maximum_hours: The maximum_hours of this DetailedShippingTimeType.  # noqa: E501
        :type: int
        """

        self._maximum_hours = maximum_hours

    @property
    def available_date(self):
        """Gets the available_date of this DetailedShippingTimeType.  # noqa: E501

        The date when the item will be available for shipping. Only displayed for items that are not currently available for shipping.  # noqa: E501

        :return: The available_date of this DetailedShippingTimeType.  # noqa: E501
        :rtype: float
        """
        return self._available_date

    @available_date.setter
    def available_date(self, available_date):
        """Sets the available_date of this DetailedShippingTimeType.

        The date when the item will be available for shipping. Only displayed for items that are not currently available for shipping.  # noqa: E501

        :param available_date: The available_date of this DetailedShippingTimeType.  # noqa: E501
        :type: float
        """

        self._available_date = available_date

    @property
    def availability_type(self):
        """Gets the availability_type of this DetailedShippingTimeType.  # noqa: E501

        Indicates whether the item is available for shipping now, or on a known or an unknown date in the future. If known, the availableDate property indicates the date that the item will be available for shipping. Possible values: NOW, FUTURE_WITHOUT_DATE, FUTURE_WITH_DATE.  # noqa: E501

        :return: The availability_type of this DetailedShippingTimeType.  # noqa: E501
        :rtype: str
        """
        return self._availability_type

    @availability_type.setter
    def availability_type(self, availability_type):
        """Sets the availability_type of this DetailedShippingTimeType.

        Indicates whether the item is available for shipping now, or on a known or an unknown date in the future. If known, the availableDate property indicates the date that the item will be available for shipping. Possible values: NOW, FUTURE_WITHOUT_DATE, FUTURE_WITH_DATE.  # noqa: E501

        :param availability_type: The availability_type of this DetailedShippingTimeType.  # noqa: E501
        :type: str
        """
        allowed_values = ["NOW", "FUTURE_WITHOUT_DATE", "FUTURE_WITH_DATE"]  # noqa: E501
        if availability_type not in allowed_values:
            raise ValueError(
                "Invalid value for `availability_type` ({0}), must be one of {1}"  # noqa: E501
                .format(availability_type, allowed_values)
            )

        self._availability_type = availability_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DetailedShippingTimeType, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DetailedShippingTimeType):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from .aws_sig_v4 import AWSSigV4
from .base_client import BaseClient
from .client import Client
from .helpers import fill_query_params, sp_endpoint
from .marketplaces import Marketplaces
from .client import SellingApiException
from .schedules import Schedules
from .report_status import ReportStatus
from .sales_enum import FirstDayOfWeek, Granularity, BuyerType
from .fulfillment_channel import FulfillmentChannel
from .deprecated import deprecated
from .notifications import NotificationType

__all__ = [
    'Client',
    'BaseClient',
    'AWSSigV4',
    'Marketplaces',
    'fill_query_params',
    'sp_endpoint',
    'SellingApiException',
    'Schedules',
    'ReportStatus',
    'FirstDayOfWeek',
    'Granularity',
    'BuyerType',
    'FulfillmentChannel',
    'deprecated',
    'NotificationType'
]



# coding: utf-8

"""
    Selling Partner API for Pricing

    The Selling Partner API for Pricing helps you programmatically retrieve product pricing and offer information for Amazon Marketplace products.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class OfferCountType(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'condition': 'str',
        'fulfillment_channel': 'FulfillmentChannelType',
        'offer_count': 'int'
    }

    attribute_map = {
        'condition': 'condition',
        'fulfillment_channel': 'fulfillmentChannel',
        'offer_count': 'OfferCount'
    }

    def __init__(self, condition=None, fulfillment_channel=None, offer_count=None):  # noqa: E501
        """OfferCountType - a model defined in Swagger"""  # noqa: E501
        self._condition = None
        self._fulfillment_channel = None
        self._offer_count = None
        self.discriminator = None
        if condition is not None:
            self.condition = condition
        if fulfillment_channel is not None:
            self.fulfillment_channel = fulfillment_channel
        if offer_count is not None:
            self.offer_count = offer_count

    @property
    def condition(self):
        """Gets the condition of this OfferCountType.  # noqa: E501

        Indicates the condition of the item. For example: New, Used, Collectible, Refurbished, or Club.  # noqa: E501

        :return: The condition of this OfferCountType.  # noqa: E501
        :rtype: str
        """
        return self._condition

    @condition.setter
    def condition(self, condition):
        """Sets the condition of this OfferCountType.

        Indicates the condition of the item. For example: New, Used, Collectible, Refurbished, or Club.  # noqa: E501

        :param condition: The condition of this OfferCountType.  # noqa: E501
        :type: str
        """

        self._condition = condition

    @property
    def fulfillment_channel(self):
        """Gets the fulfillment_channel of this OfferCountType.  # noqa: E501


        :return: The fulfillment_channel of this OfferCountType.  # noqa: E501
        :rtype: FulfillmentChannelType
        """
        return self._fulfillment_channel

    @fulfillment_channel.setter
    def fulfillment_channel(self, fulfillment_channel):
        """Sets the fulfillment_channel of this OfferCountType.


        :param fulfillment_channel: The fulfillment_channel of this OfferCountType.  # noqa: E501
        :type: FulfillmentChannelType
        """

        self._fulfillment_channel = fulfillment_channel

    @property
    def offer_count(self):
        """Gets the offer_count of this OfferCountType.  # noqa: E501

        The number of offers in a fulfillment channel that meet a specific condition.  # noqa: E501

        :return: The offer_count of this OfferCountType.  # noqa: E501
        :rtype: int
        """
        return self._offer_count

    @offer_count.setter
    def offer_count(self, offer_count):
        """Sets the offer_count of this OfferCountType.

        The number of offers in a fulfillment channel that meet a specific condition.  # noqa: E501

        :param offer_count: The offer_count of this OfferCountType.  # noqa: E501
        :type: int
        """

        self._offer_count = offer_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OfferCountType, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OfferCountType):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Finances

    The Selling Partner API for Finances helps you obtain financial information relevant to a seller's business. You can obtain financial events for a given order, financial event group, or date range without having to wait until a statement period closes. You can also obtain financial event groups for a given date range.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class ShipmentItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'seller_sku': 'str',
        'order_item_id': 'str',
        'order_adjustment_item_id': 'str',
        'quantity_shipped': 'int',
        'item_charge_list': 'ChargeComponentList',
        'item_charge_adjustment_list': 'ChargeComponentList',
        'item_fee_list': 'FeeComponentList',
        'item_fee_adjustment_list': 'FeeComponentList',
        'item_tax_withheld_list': 'TaxWithheldComponentList',
        'promotion_list': 'PromotionList',
        'promotion_adjustment_list': 'PromotionList',
        'cost_of_points_granted': 'Currency',
        'cost_of_points_returned': 'Currency'
    }

    attribute_map = {
        'seller_sku': 'SellerSKU',
        'order_item_id': 'OrderItemId',
        'order_adjustment_item_id': 'OrderAdjustmentItemId',
        'quantity_shipped': 'QuantityShipped',
        'item_charge_list': 'ItemChargeList',
        'item_charge_adjustment_list': 'ItemChargeAdjustmentList',
        'item_fee_list': 'ItemFeeList',
        'item_fee_adjustment_list': 'ItemFeeAdjustmentList',
        'item_tax_withheld_list': 'ItemTaxWithheldList',
        'promotion_list': 'PromotionList',
        'promotion_adjustment_list': 'PromotionAdjustmentList',
        'cost_of_points_granted': 'CostOfPointsGranted',
        'cost_of_points_returned': 'CostOfPointsReturned'
    }

    def __init__(self, seller_sku=None, order_item_id=None, order_adjustment_item_id=None, quantity_shipped=None, item_charge_list=None, item_charge_adjustment_list=None, item_fee_list=None, item_fee_adjustment_list=None, item_tax_withheld_list=None, promotion_list=None, promotion_adjustment_list=None, cost_of_points_granted=None, cost_of_points_returned=None):  # noqa: E501
        """ShipmentItem - a model defined in Swagger"""  # noqa: E501
        self._seller_sku = None
        self._order_item_id = None
        self._order_adjustment_item_id = None
        self._quantity_shipped = None
        self._item_charge_list = None
        self._item_charge_adjustment_list = None
        self._item_fee_list = None
        self._item_fee_adjustment_list = None
        self._item_tax_withheld_list = None
        self._promotion_list = None
        self._promotion_adjustment_list = None
        self._cost_of_points_granted = None
        self._cost_of_points_returned = None
        self.discriminator = None
        if seller_sku is not None:
            self.seller_sku = seller_sku
        if order_item_id is not None:
            self.order_item_id = order_item_id
        if order_adjustment_item_id is not None:
            self.order_adjustment_item_id = order_adjustment_item_id
        if quantity_shipped is not None:
            self.quantity_shipped = quantity_shipped
        if item_charge_list is not None:
            self.item_charge_list = item_charge_list
        if item_charge_adjustment_list is not None:
            self.item_charge_adjustment_list = item_charge_adjustment_list
        if item_fee_list is not None:
            self.item_fee_list = item_fee_list
        if item_fee_adjustment_list is not None:
            self.item_fee_adjustment_list = item_fee_adjustment_list
        if item_tax_withheld_list is not None:
            self.item_tax_withheld_list = item_tax_withheld_list
        if promotion_list is not None:
            self.promotion_list = promotion_list
        if promotion_adjustment_list is not None:
            self.promotion_adjustment_list = promotion_adjustment_list
        if cost_of_points_granted is not None:
            self.cost_of_points_granted = cost_of_points_granted
        if cost_of_points_returned is not None:
            self.cost_of_points_returned = cost_of_points_returned

    @property
    def seller_sku(self):
        """Gets the seller_sku of this ShipmentItem.  # noqa: E501

        The seller SKU of the item. The seller SKU is qualified by the seller's seller ID, which is included with every call to the Selling Partner API.  # noqa: E501

        :return: The seller_sku of this ShipmentItem.  # noqa: E501
        :rtype: str
        """
        return self._seller_sku

    @seller_sku.setter
    def seller_sku(self, seller_sku):
        """Sets the seller_sku of this ShipmentItem.

        The seller SKU of the item. The seller SKU is qualified by the seller's seller ID, which is included with every call to the Selling Partner API.  # noqa: E501

        :param seller_sku: The seller_sku of this ShipmentItem.  # noqa: E501
        :type: str
        """

        self._seller_sku = seller_sku

    @property
    def order_item_id(self):
        """Gets the order_item_id of this ShipmentItem.  # noqa: E501

        An Amazon-defined order item identifier.  # noqa: E501

        :return: The order_item_id of this ShipmentItem.  # noqa: E501
        :rtype: str
        """
        return self._order_item_id

    @order_item_id.setter
    def order_item_id(self, order_item_id):
        """Sets the order_item_id of this ShipmentItem.

        An Amazon-defined order item identifier.  # noqa: E501

        :param order_item_id: The order_item_id of this ShipmentItem.  # noqa: E501
        :type: str
        """

        self._order_item_id = order_item_id

    @property
    def order_adjustment_item_id(self):
        """Gets the order_adjustment_item_id of this ShipmentItem.  # noqa: E501

        An Amazon-defined order adjustment identifier defined for refunds, guarantee claims, and chargeback events.  # noqa: E501

        :return: The order_adjustment_item_id of this ShipmentItem.  # noqa: E501
        :rtype: str
        """
        return self._order_adjustment_item_id

    @order_adjustment_item_id.setter
    def order_adjustment_item_id(self, order_adjustment_item_id):
        """Sets the order_adjustment_item_id of this ShipmentItem.

        An Amazon-defined order adjustment identifier defined for refunds, guarantee claims, and chargeback events.  # noqa: E501

        :param order_adjustment_item_id: The order_adjustment_item_id of this ShipmentItem.  # noqa: E501
        :type: str
        """

        self._order_adjustment_item_id = order_adjustment_item_id

    @property
    def quantity_shipped(self):
        """Gets the quantity_shipped of this ShipmentItem.  # noqa: E501

        The number of items shipped.  # noqa: E501

        :return: The quantity_shipped of this ShipmentItem.  # noqa: E501
        :rtype: int
        """
        return self._quantity_shipped

    @quantity_shipped.setter
    def quantity_shipped(self, quantity_shipped):
        """Sets the quantity_shipped of this ShipmentItem.

        The number of items shipped.  # noqa: E501

        :param quantity_shipped: The quantity_shipped of this ShipmentItem.  # noqa: E501
        :type: int
        """

        self._quantity_shipped = quantity_shipped

    @property
    def item_charge_list(self):
        """Gets the item_charge_list of this ShipmentItem.  # noqa: E501


        :return: The item_charge_list of this ShipmentItem.  # noqa: E501
        :rtype: ChargeComponentList
        """
        return self._item_charge_list

    @item_charge_list.setter
    def item_charge_list(self, item_charge_list):
        """Sets the item_charge_list of this ShipmentItem.


        :param item_charge_list: The item_charge_list of this ShipmentItem.  # noqa: E501
        :type: ChargeComponentList
        """

        self._item_charge_list = item_charge_list

    @property
    def item_charge_adjustment_list(self):
        """Gets the item_charge_adjustment_list of this ShipmentItem.  # noqa: E501


        :return: The item_charge_adjustment_list of this ShipmentItem.  # noqa: E501
        :rtype: ChargeComponentList
        """
        return self._item_charge_adjustment_list

    @item_charge_adjustment_list.setter
    def item_charge_adjustment_list(self, item_charge_adjustment_list):
        """Sets the item_charge_adjustment_list of this ShipmentItem.


        :param item_charge_adjustment_list: The item_charge_adjustment_list of this ShipmentItem.  # noqa: E501
        :type: ChargeComponentList
        """

        self._item_charge_adjustment_list = item_charge_adjustment_list

    @property
    def item_fee_list(self):
        """Gets the item_fee_list of this ShipmentItem.  # noqa: E501


        :return: The item_fee_list of this ShipmentItem.  # noqa: E501
        :rtype: FeeComponentList
        """
        return self._item_fee_list

    @item_fee_list.setter
    def item_fee_list(self, item_fee_list):
        """Sets the item_fee_list of this ShipmentItem.


        :param item_fee_list: The item_fee_list of this ShipmentItem.  # noqa: E501
        :type: FeeComponentList
        """

        self._item_fee_list = item_fee_list

    @property
    def item_fee_adjustment_list(self):
        """Gets the item_fee_adjustment_list of this ShipmentItem.  # noqa: E501


        :return: The item_fee_adjustment_list of this ShipmentItem.  # noqa: E501
        :rtype: FeeComponentList
        """
        return self._item_fee_adjustment_list

    @item_fee_adjustment_list.setter
    def item_fee_adjustment_list(self, item_fee_adjustment_list):
        """Sets the item_fee_adjustment_list of this ShipmentItem.


        :param item_fee_adjustment_list: The item_fee_adjustment_list of this ShipmentItem.  # noqa: E501
        :type: FeeComponentList
        """

        self._item_fee_adjustment_list = item_fee_adjustment_list

    @property
    def item_tax_withheld_list(self):
        """Gets the item_tax_withheld_list of this ShipmentItem.  # noqa: E501


        :return: The item_tax_withheld_list of this ShipmentItem.  # noqa: E501
        :rtype: TaxWithheldComponentList
        """
        return self._item_tax_withheld_list

    @item_tax_withheld_list.setter
    def item_tax_withheld_list(self, item_tax_withheld_list):
        """Sets the item_tax_withheld_list of this ShipmentItem.


        :param item_tax_withheld_list: The item_tax_withheld_list of this ShipmentItem.  # noqa: E501
        :type: TaxWithheldComponentList
        """

        self._item_tax_withheld_list = item_tax_withheld_list

    @property
    def promotion_list(self):
        """Gets the promotion_list of this ShipmentItem.  # noqa: E501


        :return: The promotion_list of this ShipmentItem.  # noqa: E501
        :rtype: PromotionList
        """
        return self._promotion_list

    @promotion_list.setter
    def promotion_list(self, promotion_list):
        """Sets the promotion_list of this ShipmentItem.


        :param promotion_list: The promotion_list of this ShipmentItem.  # noqa: E501
        :type: PromotionList
        """

        self._promotion_list = promotion_list

    @property
    def promotion_adjustment_list(self):
        """Gets the promotion_adjustment_list of this ShipmentItem.  # noqa: E501


        :return: The promotion_adjustment_list of this ShipmentItem.  # noqa: E501
        :rtype: PromotionList
        """
        return self._promotion_adjustment_list

    @promotion_adjustment_list.setter
    def promotion_adjustment_list(self, promotion_adjustment_list):
        """Sets the promotion_adjustment_list of this ShipmentItem.


        :param promotion_adjustment_list: The promotion_adjustment_list of this ShipmentItem.  # noqa: E501
        :type: PromotionList
        """

        self._promotion_adjustment_list = promotion_adjustment_list

    @property
    def cost_of_points_granted(self):
        """Gets the cost_of_points_granted of this ShipmentItem.  # noqa: E501


        :return: The cost_of_points_granted of this ShipmentItem.  # noqa: E501
        :rtype: Currency
        """
        return self._cost_of_points_granted

    @cost_of_points_granted.setter
    def cost_of_points_granted(self, cost_of_points_granted):
        """Sets the cost_of_points_granted of this ShipmentItem.


        :param cost_of_points_granted: The cost_of_points_granted of this ShipmentItem.  # noqa: E501
        :type: Currency
        """

        self._cost_of_points_granted = cost_of_points_granted

    @property
    def cost_of_points_returned(self):
        """Gets the cost_of_points_returned of this ShipmentItem.  # noqa: E501


        :return: The cost_of_points_returned of this ShipmentItem.  # noqa: E501
        :rtype: Currency
        """
        return self._cost_of_points_returned

    @cost_of_points_returned.setter
    def cost_of_points_returned(self, cost_of_points_returned):
        """Sets the cost_of_points_returned of this ShipmentItem.


        :param cost_of_points_returned: The cost_of_points_returned of this ShipmentItem.  # noqa: E501
        :type: Currency
        """

        self._cost_of_points_returned = cost_of_points_returned

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ShipmentItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShipmentItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from sp_api.base.helpers import sp_endpoint
from sp_api.api.sellers.models.get_marketplace_participations_response import GetMarketplaceParticipationsResponse
from sp_api.base import Client, Marketplaces


class Sellers(Client):
    def __init__(self, marketplace=Marketplaces.US, refresh_token=None):
        super().__init__(marketplace, refresh_token)

    @sp_endpoint('/sellers/v1/marketplaceParticipations')
    def get_marketplace_participation(self, **kwargs):
        return GetMarketplaceParticipationsResponse(**self._request(kwargs.pop('path')).json())



# coding: utf-8

"""
    Selling Partner API for Finances

    The Selling Partner API for Finances helps you obtain financial information relevant to a seller's business. You can obtain financial events for a given order, financial event group, or date range without having to wait until a statement period closes. You can also obtain financial event groups for a given date range.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class RetrochargeEvent(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'retrocharge_event_type': 'str',
        'amazon_order_id': 'str',
        'posted_date': 'ModelDate',
        'base_tax': 'Currency',
        'shipping_tax': 'Currency',
        'marketplace_name': 'str',
        'retrocharge_tax_withheld_list': 'TaxWithheldComponentList'
    }

    attribute_map = {
        'retrocharge_event_type': 'RetrochargeEventType',
        'amazon_order_id': 'AmazonOrderId',
        'posted_date': 'PostedDate',
        'base_tax': 'BaseTax',
        'shipping_tax': 'ShippingTax',
        'marketplace_name': 'MarketplaceName',
        'retrocharge_tax_withheld_list': 'RetrochargeTaxWithheldList'
    }

    def __init__(self, retrocharge_event_type=None, amazon_order_id=None, posted_date=None, base_tax=None, shipping_tax=None, marketplace_name=None, retrocharge_tax_withheld_list=None):  # noqa: E501
        """RetrochargeEvent - a model defined in Swagger"""  # noqa: E501
        self._retrocharge_event_type = None
        self._amazon_order_id = None
        self._posted_date = None
        self._base_tax = None
        self._shipping_tax = None
        self._marketplace_name = None
        self._retrocharge_tax_withheld_list = None
        self.discriminator = None
        if retrocharge_event_type is not None:
            self.retrocharge_event_type = retrocharge_event_type
        if amazon_order_id is not None:
            self.amazon_order_id = amazon_order_id
        if posted_date is not None:
            self.posted_date = posted_date
        if base_tax is not None:
            self.base_tax = base_tax
        if shipping_tax is not None:
            self.shipping_tax = shipping_tax
        if marketplace_name is not None:
            self.marketplace_name = marketplace_name
        if retrocharge_tax_withheld_list is not None:
            self.retrocharge_tax_withheld_list = retrocharge_tax_withheld_list

    @property
    def retrocharge_event_type(self):
        """Gets the retrocharge_event_type of this RetrochargeEvent.  # noqa: E501

        The type of event.  Possible values:  * Retrocharge  * RetrochargeReversal  # noqa: E501

        :return: The retrocharge_event_type of this RetrochargeEvent.  # noqa: E501
        :rtype: str
        """
        return self._retrocharge_event_type

    @retrocharge_event_type.setter
    def retrocharge_event_type(self, retrocharge_event_type):
        """Sets the retrocharge_event_type of this RetrochargeEvent.

        The type of event.  Possible values:  * Retrocharge  * RetrochargeReversal  # noqa: E501

        :param retrocharge_event_type: The retrocharge_event_type of this RetrochargeEvent.  # noqa: E501
        :type: str
        """

        self._retrocharge_event_type = retrocharge_event_type

    @property
    def amazon_order_id(self):
        """Gets the amazon_order_id of this RetrochargeEvent.  # noqa: E501

        An Amazon-defined identifier for an order.  # noqa: E501

        :return: The amazon_order_id of this RetrochargeEvent.  # noqa: E501
        :rtype: str
        """
        return self._amazon_order_id

    @amazon_order_id.setter
    def amazon_order_id(self, amazon_order_id):
        """Sets the amazon_order_id of this RetrochargeEvent.

        An Amazon-defined identifier for an order.  # noqa: E501

        :param amazon_order_id: The amazon_order_id of this RetrochargeEvent.  # noqa: E501
        :type: str
        """

        self._amazon_order_id = amazon_order_id

    @property
    def posted_date(self):
        """Gets the posted_date of this RetrochargeEvent.  # noqa: E501


        :return: The posted_date of this RetrochargeEvent.  # noqa: E501
        :rtype: ModelDate
        """
        return self._posted_date

    @posted_date.setter
    def posted_date(self, posted_date):
        """Sets the posted_date of this RetrochargeEvent.


        :param posted_date: The posted_date of this RetrochargeEvent.  # noqa: E501
        :type: ModelDate
        """

        self._posted_date = posted_date

    @property
    def base_tax(self):
        """Gets the base_tax of this RetrochargeEvent.  # noqa: E501


        :return: The base_tax of this RetrochargeEvent.  # noqa: E501
        :rtype: Currency
        """
        return self._base_tax

    @base_tax.setter
    def base_tax(self, base_tax):
        """Sets the base_tax of this RetrochargeEvent.


        :param base_tax: The base_tax of this RetrochargeEvent.  # noqa: E501
        :type: Currency
        """

        self._base_tax = base_tax

    @property
    def shipping_tax(self):
        """Gets the shipping_tax of this RetrochargeEvent.  # noqa: E501


        :return: The shipping_tax of this RetrochargeEvent.  # noqa: E501
        :rtype: Currency
        """
        return self._shipping_tax

    @shipping_tax.setter
    def shipping_tax(self, shipping_tax):
        """Sets the shipping_tax of this RetrochargeEvent.


        :param shipping_tax: The shipping_tax of this RetrochargeEvent.  # noqa: E501
        :type: Currency
        """

        self._shipping_tax = shipping_tax

    @property
    def marketplace_name(self):
        """Gets the marketplace_name of this RetrochargeEvent.  # noqa: E501

        The name of the marketplace where the retrocharge event occurred.  # noqa: E501

        :return: The marketplace_name of this RetrochargeEvent.  # noqa: E501
        :rtype: str
        """
        return self._marketplace_name

    @marketplace_name.setter
    def marketplace_name(self, marketplace_name):
        """Sets the marketplace_name of this RetrochargeEvent.

        The name of the marketplace where the retrocharge event occurred.  # noqa: E501

        :param marketplace_name: The marketplace_name of this RetrochargeEvent.  # noqa: E501
        :type: str
        """

        self._marketplace_name = marketplace_name

    @property
    def retrocharge_tax_withheld_list(self):
        """Gets the retrocharge_tax_withheld_list of this RetrochargeEvent.  # noqa: E501


        :return: The retrocharge_tax_withheld_list of this RetrochargeEvent.  # noqa: E501
        :rtype: TaxWithheldComponentList
        """
        return self._retrocharge_tax_withheld_list

    @retrocharge_tax_withheld_list.setter
    def retrocharge_tax_withheld_list(self, retrocharge_tax_withheld_list):
        """Sets the retrocharge_tax_withheld_list of this RetrochargeEvent.


        :param retrocharge_tax_withheld_list: The retrocharge_tax_withheld_list of this RetrochargeEvent.  # noqa: E501
        :type: TaxWithheldComponentList
        """

        self._retrocharge_tax_withheld_list = retrocharge_tax_withheld_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RetrochargeEvent, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RetrochargeEvent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Finances

    The Selling Partner API for Finances helps you obtain financial information relevant to a seller's business. You can obtain financial events for a given order, financial event group, or date range without having to wait until a statement period closes. You can also obtain financial event groups for a given date range.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class ServiceFeeEvent(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amazon_order_id': 'str',
        'fee_reason': 'str',
        'fee_list': 'FeeComponentList',
        'seller_sku': 'str',
        'fn_sku': 'str',
        'fee_description': 'str',
        'asin': 'str'
    }

    attribute_map = {
        'amazon_order_id': 'AmazonOrderId',
        'fee_reason': 'FeeReason',
        'fee_list': 'FeeList',
        'seller_sku': 'SellerSKU',
        'fn_sku': 'FnSKU',
        'fee_description': 'FeeDescription',
        'asin': 'ASIN'
    }

    def __init__(self, amazon_order_id=None, fee_reason=None, fee_list=None, seller_sku=None, fn_sku=None, fee_description=None, asin=None):  # noqa: E501
        """ServiceFeeEvent - a model defined in Swagger"""  # noqa: E501
        self._amazon_order_id = None
        self._fee_reason = None
        self._fee_list = None
        self._seller_sku = None
        self._fn_sku = None
        self._fee_description = None
        self._asin = None
        self.discriminator = None
        if amazon_order_id is not None:
            self.amazon_order_id = amazon_order_id
        if fee_reason is not None:
            self.fee_reason = fee_reason
        if fee_list is not None:
            self.fee_list = fee_list
        if seller_sku is not None:
            self.seller_sku = seller_sku
        if fn_sku is not None:
            self.fn_sku = fn_sku
        if fee_description is not None:
            self.fee_description = fee_description
        if asin is not None:
            self.asin = asin

    @property
    def amazon_order_id(self):
        """Gets the amazon_order_id of this ServiceFeeEvent.  # noqa: E501

        An Amazon-defined identifier for an order.  # noqa: E501

        :return: The amazon_order_id of this ServiceFeeEvent.  # noqa: E501
        :rtype: str
        """
        return self._amazon_order_id

    @amazon_order_id.setter
    def amazon_order_id(self, amazon_order_id):
        """Sets the amazon_order_id of this ServiceFeeEvent.

        An Amazon-defined identifier for an order.  # noqa: E501

        :param amazon_order_id: The amazon_order_id of this ServiceFeeEvent.  # noqa: E501
        :type: str
        """

        self._amazon_order_id = amazon_order_id

    @property
    def fee_reason(self):
        """Gets the fee_reason of this ServiceFeeEvent.  # noqa: E501

        A short description of the service fee reason.  # noqa: E501

        :return: The fee_reason of this ServiceFeeEvent.  # noqa: E501
        :rtype: str
        """
        return self._fee_reason

    @fee_reason.setter
    def fee_reason(self, fee_reason):
        """Sets the fee_reason of this ServiceFeeEvent.

        A short description of the service fee reason.  # noqa: E501

        :param fee_reason: The fee_reason of this ServiceFeeEvent.  # noqa: E501
        :type: str
        """

        self._fee_reason = fee_reason

    @property
    def fee_list(self):
        """Gets the fee_list of this ServiceFeeEvent.  # noqa: E501


        :return: The fee_list of this ServiceFeeEvent.  # noqa: E501
        :rtype: FeeComponentList
        """
        return self._fee_list

    @fee_list.setter
    def fee_list(self, fee_list):
        """Sets the fee_list of this ServiceFeeEvent.


        :param fee_list: The fee_list of this ServiceFeeEvent.  # noqa: E501
        :type: FeeComponentList
        """

        self._fee_list = fee_list

    @property
    def seller_sku(self):
        """Gets the seller_sku of this ServiceFeeEvent.  # noqa: E501

        The seller SKU of the item. The seller SKU is qualified by the seller's seller ID, which is included with every call to the Selling Partner API.  # noqa: E501

        :return: The seller_sku of this ServiceFeeEvent.  # noqa: E501
        :rtype: str
        """
        return self._seller_sku

    @seller_sku.setter
    def seller_sku(self, seller_sku):
        """Sets the seller_sku of this ServiceFeeEvent.

        The seller SKU of the item. The seller SKU is qualified by the seller's seller ID, which is included with every call to the Selling Partner API.  # noqa: E501

        :param seller_sku: The seller_sku of this ServiceFeeEvent.  # noqa: E501
        :type: str
        """

        self._seller_sku = seller_sku

    @property
    def fn_sku(self):
        """Gets the fn_sku of this ServiceFeeEvent.  # noqa: E501

        A unique identifier assigned by Amazon to products stored in and fulfilled from an Amazon fulfillment center.  # noqa: E501

        :return: The fn_sku of this ServiceFeeEvent.  # noqa: E501
        :rtype: str
        """
        return self._fn_sku

    @fn_sku.setter
    def fn_sku(self, fn_sku):
        """Sets the fn_sku of this ServiceFeeEvent.

        A unique identifier assigned by Amazon to products stored in and fulfilled from an Amazon fulfillment center.  # noqa: E501

        :param fn_sku: The fn_sku of this ServiceFeeEvent.  # noqa: E501
        :type: str
        """

        self._fn_sku = fn_sku

    @property
    def fee_description(self):
        """Gets the fee_description of this ServiceFeeEvent.  # noqa: E501

        A short description of the service fee event.  # noqa: E501

        :return: The fee_description of this ServiceFeeEvent.  # noqa: E501
        :rtype: str
        """
        return self._fee_description

    @fee_description.setter
    def fee_description(self, fee_description):
        """Sets the fee_description of this ServiceFeeEvent.

        A short description of the service fee event.  # noqa: E501

        :param fee_description: The fee_description of this ServiceFeeEvent.  # noqa: E501
        :type: str
        """

        self._fee_description = fee_description

    @property
    def asin(self):
        """Gets the asin of this ServiceFeeEvent.  # noqa: E501

        The Amazon Standard Identification Number (ASIN) of the item.  # noqa: E501

        :return: The asin of this ServiceFeeEvent.  # noqa: E501
        :rtype: str
        """
        return self._asin

    @asin.setter
    def asin(self, asin):
        """Sets the asin of this ServiceFeeEvent.

        The Amazon Standard Identification Number (ASIN) of the item.  # noqa: E501

        :param asin: The asin of this ServiceFeeEvent.  # noqa: E501
        :type: str
        """

        self._asin = asin

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ServiceFeeEvent, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServiceFeeEvent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Finances

    The Selling Partner API for Finances helps you obtain financial information relevant to a seller's business. You can obtain financial events for a given order, financial event group, or date range without having to wait until a statement period closes. You can also obtain financial event groups for a given date range.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class SAFETReimbursementItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'item_charge_list': 'ChargeComponentList',
        'product_description': 'str',
        'quantity': 'str'
    }

    attribute_map = {
        'item_charge_list': 'itemChargeList',
        'product_description': 'productDescription',
        'quantity': 'quantity'
    }

    def __init__(self, item_charge_list=None, product_description=None, quantity=None):  # noqa: E501
        """SAFETReimbursementItem - a model defined in Swagger"""  # noqa: E501
        self._item_charge_list = None
        self._product_description = None
        self._quantity = None
        self.discriminator = None
        if item_charge_list is not None:
            self.item_charge_list = item_charge_list
        if product_description is not None:
            self.product_description = product_description
        if quantity is not None:
            self.quantity = quantity

    @property
    def item_charge_list(self):
        """Gets the item_charge_list of this SAFETReimbursementItem.  # noqa: E501


        :return: The item_charge_list of this SAFETReimbursementItem.  # noqa: E501
        :rtype: ChargeComponentList
        """
        return self._item_charge_list

    @item_charge_list.setter
    def item_charge_list(self, item_charge_list):
        """Sets the item_charge_list of this SAFETReimbursementItem.


        :param item_charge_list: The item_charge_list of this SAFETReimbursementItem.  # noqa: E501
        :type: ChargeComponentList
        """

        self._item_charge_list = item_charge_list

    @property
    def product_description(self):
        """Gets the product_description of this SAFETReimbursementItem.  # noqa: E501

        The description of the item as shown on the product detail page on the retail website.  # noqa: E501

        :return: The product_description of this SAFETReimbursementItem.  # noqa: E501
        :rtype: str
        """
        return self._product_description

    @product_description.setter
    def product_description(self, product_description):
        """Sets the product_description of this SAFETReimbursementItem.

        The description of the item as shown on the product detail page on the retail website.  # noqa: E501

        :param product_description: The product_description of this SAFETReimbursementItem.  # noqa: E501
        :type: str
        """

        self._product_description = product_description

    @property
    def quantity(self):
        """Gets the quantity of this SAFETReimbursementItem.  # noqa: E501

        The number of units of the item being reimbursed.  # noqa: E501

        :return: The quantity of this SAFETReimbursementItem.  # noqa: E501
        :rtype: str
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this SAFETReimbursementItem.

        The number of units of the item being reimbursed.  # noqa: E501

        :param quantity: The quantity of this SAFETReimbursementItem.  # noqa: E501
        :type: str
        """

        self._quantity = quantity

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SAFETReimbursementItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SAFETReimbursementItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
